# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ComputedUsage(object):
    """
    Computed Usage Summary object
    """

    #: A constant which can be used with the type property of a ComputedUsage.
    #: This constant has a value of "PROMOTION"
    TYPE_PROMOTION = "PROMOTION"

    #: A constant which can be used with the type property of a ComputedUsage.
    #: This constant has a value of "DO_NOT_BILL"
    TYPE_DO_NOT_BILL = "DO_NOT_BILL"

    #: A constant which can be used with the type property of a ComputedUsage.
    #: This constant has a value of "USAGE"
    TYPE_USAGE = "USAGE"

    #: A constant which can be used with the type property of a ComputedUsage.
    #: This constant has a value of "COMMIT"
    TYPE_COMMIT = "COMMIT"

    #: A constant which can be used with the type property of a ComputedUsage.
    #: This constant has a value of "OVERAGE"
    TYPE_OVERAGE = "OVERAGE"

    #: A constant which can be used with the type property of a ComputedUsage.
    #: This constant has a value of "PAY_AS_YOU_GO"
    TYPE_PAY_AS_YOU_GO = "PAY_AS_YOU_GO"

    #: A constant which can be used with the type property of a ComputedUsage.
    #: This constant has a value of "MONTHLY_MINIMUM"
    TYPE_MONTHLY_MINIMUM = "MONTHLY_MINIMUM"

    #: A constant which can be used with the type property of a ComputedUsage.
    #: This constant has a value of "DELAYED_USAGE_INVOICE_TIMING"
    TYPE_DELAYED_USAGE_INVOICE_TIMING = "DELAYED_USAGE_INVOICE_TIMING"

    #: A constant which can be used with the type property of a ComputedUsage.
    #: This constant has a value of "DELAYED_USAGE_COMMITMENT_EXP"
    TYPE_DELAYED_USAGE_COMMITMENT_EXP = "DELAYED_USAGE_COMMITMENT_EXP"

    #: A constant which can be used with the type property of a ComputedUsage.
    #: This constant has a value of "ON_ACCOUNT_CREDIT"
    TYPE_ON_ACCOUNT_CREDIT = "ON_ACCOUNT_CREDIT"

    #: A constant which can be used with the type property of a ComputedUsage.
    #: This constant has a value of "SERVICE_CREDIT"
    TYPE_SERVICE_CREDIT = "SERVICE_CREDIT"

    #: A constant which can be used with the type property of a ComputedUsage.
    #: This constant has a value of "COMMITMENT_EXPIRATION"
    TYPE_COMMITMENT_EXPIRATION = "COMMITMENT_EXPIRATION"

    #: A constant which can be used with the type property of a ComputedUsage.
    #: This constant has a value of "FUNDED_ALLOCATION"
    TYPE_FUNDED_ALLOCATION = "FUNDED_ALLOCATION"

    #: A constant which can be used with the type property of a ComputedUsage.
    #: This constant has a value of "DONOT_BILL_USAGE_POST_TERMINATION"
    TYPE_DONOT_BILL_USAGE_POST_TERMINATION = "DONOT_BILL_USAGE_POST_TERMINATION"

    #: A constant which can be used with the type property of a ComputedUsage.
    #: This constant has a value of "DELAYED_USAGE_POST_TERMINATION"
    TYPE_DELAYED_USAGE_POST_TERMINATION = "DELAYED_USAGE_POST_TERMINATION"

    def __init__(self, **kwargs):
        """
        Initializes a new ComputedUsage object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_created:
            The value to assign to the time_created property of this ComputedUsage.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this ComputedUsage.
        :type time_updated: datetime

        :param parent_subscribed_service_id:
            The value to assign to the parent_subscribed_service_id property of this ComputedUsage.
        :type parent_subscribed_service_id: str

        :param parent_product:
            The value to assign to the parent_product property of this ComputedUsage.
        :type parent_product: oci.osub_usage.models.Product

        :param plan_number:
            The value to assign to the plan_number property of this ComputedUsage.
        :type plan_number: str

        :param currency_code:
            The value to assign to the currency_code property of this ComputedUsage.
        :type currency_code: str

        :param rate_card_tierd_id:
            The value to assign to the rate_card_tierd_id property of this ComputedUsage.
        :type rate_card_tierd_id: str

        :param rate_card_id:
            The value to assign to the rate_card_id property of this ComputedUsage.
        :type rate_card_id: str

        :param compute_source:
            The value to assign to the compute_source property of this ComputedUsage.
        :type compute_source: str

        :param data_center:
            The value to assign to the data_center property of this ComputedUsage.
        :type data_center: str

        :param mqs_message_id:
            The value to assign to the mqs_message_id property of this ComputedUsage.
        :type mqs_message_id: str

        :param id:
            The value to assign to the id property of this ComputedUsage.
        :type id: str

        :param quantity:
            The value to assign to the quantity property of this ComputedUsage.
        :type quantity: str

        :param usage_number:
            The value to assign to the usage_number property of this ComputedUsage.
        :type usage_number: str

        :param original_usage_number:
            The value to assign to the original_usage_number property of this ComputedUsage.
        :type original_usage_number: str

        :param commitment_service_id:
            The value to assign to the commitment_service_id property of this ComputedUsage.
        :type commitment_service_id: str

        :param is_invoiced:
            The value to assign to the is_invoiced property of this ComputedUsage.
        :type is_invoiced: bool

        :param type:
            The value to assign to the type property of this ComputedUsage.
            Allowed values for this property are: "PROMOTION", "DO_NOT_BILL", "USAGE", "COMMIT", "OVERAGE", "PAY_AS_YOU_GO", "MONTHLY_MINIMUM", "DELAYED_USAGE_INVOICE_TIMING", "DELAYED_USAGE_COMMITMENT_EXP", "ON_ACCOUNT_CREDIT", "SERVICE_CREDIT", "COMMITMENT_EXPIRATION", "FUNDED_ALLOCATION", "DONOT_BILL_USAGE_POST_TERMINATION", "DELAYED_USAGE_POST_TERMINATION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param time_of_arrival:
            The value to assign to the time_of_arrival property of this ComputedUsage.
        :type time_of_arrival: datetime

        :param time_metered_on:
            The value to assign to the time_metered_on property of this ComputedUsage.
        :type time_metered_on: datetime

        :param net_unit_price:
            The value to assign to the net_unit_price property of this ComputedUsage.
        :type net_unit_price: str

        :param cost_rounded:
            The value to assign to the cost_rounded property of this ComputedUsage.
        :type cost_rounded: str

        :param cost:
            The value to assign to the cost property of this ComputedUsage.
        :type cost: str

        :param product:
            The value to assign to the product property of this ComputedUsage.
        :type product: oci.osub_usage.models.Product

        :param unit_of_measure:
            The value to assign to the unit_of_measure property of this ComputedUsage.
        :type unit_of_measure: str

        """
        self.swagger_types = {
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'parent_subscribed_service_id': 'str',
            'parent_product': 'Product',
            'plan_number': 'str',
            'currency_code': 'str',
            'rate_card_tierd_id': 'str',
            'rate_card_id': 'str',
            'compute_source': 'str',
            'data_center': 'str',
            'mqs_message_id': 'str',
            'id': 'str',
            'quantity': 'str',
            'usage_number': 'str',
            'original_usage_number': 'str',
            'commitment_service_id': 'str',
            'is_invoiced': 'bool',
            'type': 'str',
            'time_of_arrival': 'datetime',
            'time_metered_on': 'datetime',
            'net_unit_price': 'str',
            'cost_rounded': 'str',
            'cost': 'str',
            'product': 'Product',
            'unit_of_measure': 'str'
        }

        self.attribute_map = {
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'parent_subscribed_service_id': 'parentSubscribedServiceId',
            'parent_product': 'parentProduct',
            'plan_number': 'planNumber',
            'currency_code': 'currencyCode',
            'rate_card_tierd_id': 'rateCardTierdId',
            'rate_card_id': 'rateCardId',
            'compute_source': 'computeSource',
            'data_center': 'dataCenter',
            'mqs_message_id': 'mqsMessageId',
            'id': 'id',
            'quantity': 'quantity',
            'usage_number': 'usageNumber',
            'original_usage_number': 'originalUsageNumber',
            'commitment_service_id': 'commitmentServiceId',
            'is_invoiced': 'isInvoiced',
            'type': 'type',
            'time_of_arrival': 'timeOfArrival',
            'time_metered_on': 'timeMeteredOn',
            'net_unit_price': 'netUnitPrice',
            'cost_rounded': 'costRounded',
            'cost': 'cost',
            'product': 'product',
            'unit_of_measure': 'unitOfMeasure'
        }

        self._time_created = None
        self._time_updated = None
        self._parent_subscribed_service_id = None
        self._parent_product = None
        self._plan_number = None
        self._currency_code = None
        self._rate_card_tierd_id = None
        self._rate_card_id = None
        self._compute_source = None
        self._data_center = None
        self._mqs_message_id = None
        self._id = None
        self._quantity = None
        self._usage_number = None
        self._original_usage_number = None
        self._commitment_service_id = None
        self._is_invoiced = None
        self._type = None
        self._time_of_arrival = None
        self._time_metered_on = None
        self._net_unit_price = None
        self._cost_rounded = None
        self._cost = None
        self._product = None
        self._unit_of_measure = None

    @property
    def time_created(self):
        """
        Gets the time_created of this ComputedUsage.
        Computed Usage created time, expressed in RFC 3339 timestamp format.


        :return: The time_created of this ComputedUsage.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ComputedUsage.
        Computed Usage created time, expressed in RFC 3339 timestamp format.


        :param time_created: The time_created of this ComputedUsage.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this ComputedUsage.
        Computed Usage updated time, expressed in RFC 3339 timestamp format.


        :return: The time_updated of this ComputedUsage.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this ComputedUsage.
        Computed Usage updated time, expressed in RFC 3339 timestamp format.


        :param time_updated: The time_updated of this ComputedUsage.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def parent_subscribed_service_id(self):
        """
        Gets the parent_subscribed_service_id of this ComputedUsage.
        Subscribed service line parent id


        :return: The parent_subscribed_service_id of this ComputedUsage.
        :rtype: str
        """
        return self._parent_subscribed_service_id

    @parent_subscribed_service_id.setter
    def parent_subscribed_service_id(self, parent_subscribed_service_id):
        """
        Sets the parent_subscribed_service_id of this ComputedUsage.
        Subscribed service line parent id


        :param parent_subscribed_service_id: The parent_subscribed_service_id of this ComputedUsage.
        :type: str
        """
        self._parent_subscribed_service_id = parent_subscribed_service_id

    @property
    def parent_product(self):
        """
        Gets the parent_product of this ComputedUsage.

        :return: The parent_product of this ComputedUsage.
        :rtype: oci.osub_usage.models.Product
        """
        return self._parent_product

    @parent_product.setter
    def parent_product(self, parent_product):
        """
        Sets the parent_product of this ComputedUsage.

        :param parent_product: The parent_product of this ComputedUsage.
        :type: oci.osub_usage.models.Product
        """
        self._parent_product = parent_product

    @property
    def plan_number(self):
        """
        Gets the plan_number of this ComputedUsage.
        Subscription plan number


        :return: The plan_number of this ComputedUsage.
        :rtype: str
        """
        return self._plan_number

    @plan_number.setter
    def plan_number(self, plan_number):
        """
        Sets the plan_number of this ComputedUsage.
        Subscription plan number


        :param plan_number: The plan_number of this ComputedUsage.
        :type: str
        """
        self._plan_number = plan_number

    @property
    def currency_code(self):
        """
        Gets the currency_code of this ComputedUsage.
        Currency code


        :return: The currency_code of this ComputedUsage.
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """
        Sets the currency_code of this ComputedUsage.
        Currency code


        :param currency_code: The currency_code of this ComputedUsage.
        :type: str
        """
        self._currency_code = currency_code

    @property
    def rate_card_tierd_id(self):
        """
        Gets the rate_card_tierd_id of this ComputedUsage.
        References the tier in the ratecard for that usage (OCI will be using the same reference to cross-reference for correctness on the usage csv report), comes from Entity OBSCNTR_IPT_PRODUCTTIER.


        :return: The rate_card_tierd_id of this ComputedUsage.
        :rtype: str
        """
        return self._rate_card_tierd_id

    @rate_card_tierd_id.setter
    def rate_card_tierd_id(self, rate_card_tierd_id):
        """
        Sets the rate_card_tierd_id of this ComputedUsage.
        References the tier in the ratecard for that usage (OCI will be using the same reference to cross-reference for correctness on the usage csv report), comes from Entity OBSCNTR_IPT_PRODUCTTIER.


        :param rate_card_tierd_id: The rate_card_tierd_id of this ComputedUsage.
        :type: str
        """
        self._rate_card_tierd_id = rate_card_tierd_id

    @property
    def rate_card_id(self):
        """
        Gets the rate_card_id of this ComputedUsage.
        Ratecard Id at subscribed service level


        :return: The rate_card_id of this ComputedUsage.
        :rtype: str
        """
        return self._rate_card_id

    @rate_card_id.setter
    def rate_card_id(self, rate_card_id):
        """
        Sets the rate_card_id of this ComputedUsage.
        Ratecard Id at subscribed service level


        :param rate_card_id: The rate_card_id of this ComputedUsage.
        :type: str
        """
        self._rate_card_id = rate_card_id

    @property
    def compute_source(self):
        """
        Gets the compute_source of this ComputedUsage.
        SPM Internal compute records source .


        :return: The compute_source of this ComputedUsage.
        :rtype: str
        """
        return self._compute_source

    @compute_source.setter
    def compute_source(self, compute_source):
        """
        Sets the compute_source of this ComputedUsage.
        SPM Internal compute records source .


        :param compute_source: The compute_source of this ComputedUsage.
        :type: str
        """
        self._compute_source = compute_source

    @property
    def data_center(self):
        """
        Gets the data_center of this ComputedUsage.
        Data Center Attribute as sent by MQS to SPM.


        :return: The data_center of this ComputedUsage.
        :rtype: str
        """
        return self._data_center

    @data_center.setter
    def data_center(self, data_center):
        """
        Sets the data_center of this ComputedUsage.
        Data Center Attribute as sent by MQS to SPM.


        :param data_center: The data_center of this ComputedUsage.
        :type: str
        """
        self._data_center = data_center

    @property
    def mqs_message_id(self):
        """
        Gets the mqs_message_id of this ComputedUsage.
        MQS Identfier send to SPM , SPM does not transform this attribute and is received as is.


        :return: The mqs_message_id of this ComputedUsage.
        :rtype: str
        """
        return self._mqs_message_id

    @mqs_message_id.setter
    def mqs_message_id(self, mqs_message_id):
        """
        Sets the mqs_message_id of this ComputedUsage.
        MQS Identfier send to SPM , SPM does not transform this attribute and is received as is.


        :param mqs_message_id: The mqs_message_id of this ComputedUsage.
        :type: str
        """
        self._mqs_message_id = mqs_message_id

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ComputedUsage.
        SPM Internal computed usage Id , 32 character string


        :return: The id of this ComputedUsage.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ComputedUsage.
        SPM Internal computed usage Id , 32 character string


        :param id: The id of this ComputedUsage.
        :type: str
        """
        self._id = id

    @property
    def quantity(self):
        """
        Gets the quantity of this ComputedUsage.
        Total Quantity that was used for computation


        :return: The quantity of this ComputedUsage.
        :rtype: str
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """
        Sets the quantity of this ComputedUsage.
        Total Quantity that was used for computation


        :param quantity: The quantity of this ComputedUsage.
        :type: str
        """
        self._quantity = quantity

    @property
    def usage_number(self):
        """
        Gets the usage_number of this ComputedUsage.
        SPM Internal usage Line number identifier in SPM coming from Metered Services entity.


        :return: The usage_number of this ComputedUsage.
        :rtype: str
        """
        return self._usage_number

    @usage_number.setter
    def usage_number(self, usage_number):
        """
        Sets the usage_number of this ComputedUsage.
        SPM Internal usage Line number identifier in SPM coming from Metered Services entity.


        :param usage_number: The usage_number of this ComputedUsage.
        :type: str
        """
        self._usage_number = usage_number

    @property
    def original_usage_number(self):
        """
        Gets the original_usage_number of this ComputedUsage.
        SPM Internal Original usage Line number identifier in SPM coming from Metered Services entity.


        :return: The original_usage_number of this ComputedUsage.
        :rtype: str
        """
        return self._original_usage_number

    @original_usage_number.setter
    def original_usage_number(self, original_usage_number):
        """
        Sets the original_usage_number of this ComputedUsage.
        SPM Internal Original usage Line number identifier in SPM coming from Metered Services entity.


        :param original_usage_number: The original_usage_number of this ComputedUsage.
        :type: str
        """
        self._original_usage_number = original_usage_number

    @property
    def commitment_service_id(self):
        """
        Gets the commitment_service_id of this ComputedUsage.
        Subscribed service commitmentId.


        :return: The commitment_service_id of this ComputedUsage.
        :rtype: str
        """
        return self._commitment_service_id

    @commitment_service_id.setter
    def commitment_service_id(self, commitment_service_id):
        """
        Sets the commitment_service_id of this ComputedUsage.
        Subscribed service commitmentId.


        :param commitment_service_id: The commitment_service_id of this ComputedUsage.
        :type: str
        """
        self._commitment_service_id = commitment_service_id

    @property
    def is_invoiced(self):
        """
        Gets the is_invoiced of this ComputedUsage.
        Invoicing status for the aggregated compute usage


        :return: The is_invoiced of this ComputedUsage.
        :rtype: bool
        """
        return self._is_invoiced

    @is_invoiced.setter
    def is_invoiced(self, is_invoiced):
        """
        Sets the is_invoiced of this ComputedUsage.
        Invoicing status for the aggregated compute usage


        :param is_invoiced: The is_invoiced of this ComputedUsage.
        :type: bool
        """
        self._is_invoiced = is_invoiced

    @property
    def type(self):
        """
        Gets the type of this ComputedUsage.
        Usage compute type in SPM.

        Allowed values for this property are: "PROMOTION", "DO_NOT_BILL", "USAGE", "COMMIT", "OVERAGE", "PAY_AS_YOU_GO", "MONTHLY_MINIMUM", "DELAYED_USAGE_INVOICE_TIMING", "DELAYED_USAGE_COMMITMENT_EXP", "ON_ACCOUNT_CREDIT", "SERVICE_CREDIT", "COMMITMENT_EXPIRATION", "FUNDED_ALLOCATION", "DONOT_BILL_USAGE_POST_TERMINATION", "DELAYED_USAGE_POST_TERMINATION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this ComputedUsage.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ComputedUsage.
        Usage compute type in SPM.


        :param type: The type of this ComputedUsage.
        :type: str
        """
        allowed_values = ["PROMOTION", "DO_NOT_BILL", "USAGE", "COMMIT", "OVERAGE", "PAY_AS_YOU_GO", "MONTHLY_MINIMUM", "DELAYED_USAGE_INVOICE_TIMING", "DELAYED_USAGE_COMMITMENT_EXP", "ON_ACCOUNT_CREDIT", "SERVICE_CREDIT", "COMMITMENT_EXPIRATION", "FUNDED_ALLOCATION", "DONOT_BILL_USAGE_POST_TERMINATION", "DELAYED_USAGE_POST_TERMINATION"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def time_of_arrival(self):
        """
        Gets the time_of_arrival of this ComputedUsage.
        Usae computation date, expressed in RFC 3339 timestamp format.


        :return: The time_of_arrival of this ComputedUsage.
        :rtype: datetime
        """
        return self._time_of_arrival

    @time_of_arrival.setter
    def time_of_arrival(self, time_of_arrival):
        """
        Sets the time_of_arrival of this ComputedUsage.
        Usae computation date, expressed in RFC 3339 timestamp format.


        :param time_of_arrival: The time_of_arrival of this ComputedUsage.
        :type: datetime
        """
        self._time_of_arrival = time_of_arrival

    @property
    def time_metered_on(self):
        """
        Gets the time_metered_on of this ComputedUsage.
        Metered Service date, expressed in RFC 3339 timestamp format.


        :return: The time_metered_on of this ComputedUsage.
        :rtype: datetime
        """
        return self._time_metered_on

    @time_metered_on.setter
    def time_metered_on(self, time_metered_on):
        """
        Sets the time_metered_on of this ComputedUsage.
        Metered Service date, expressed in RFC 3339 timestamp format.


        :param time_metered_on: The time_metered_on of this ComputedUsage.
        :type: datetime
        """
        self._time_metered_on = time_metered_on

    @property
    def net_unit_price(self):
        """
        Gets the net_unit_price of this ComputedUsage.
        Net Unit Price for the product in consideration, price actual.


        :return: The net_unit_price of this ComputedUsage.
        :rtype: str
        """
        return self._net_unit_price

    @net_unit_price.setter
    def net_unit_price(self, net_unit_price):
        """
        Sets the net_unit_price of this ComputedUsage.
        Net Unit Price for the product in consideration, price actual.


        :param net_unit_price: The net_unit_price of this ComputedUsage.
        :type: str
        """
        self._net_unit_price = net_unit_price

    @property
    def cost_rounded(self):
        """
        Gets the cost_rounded of this ComputedUsage.
        Computed Line Amount rounded.


        :return: The cost_rounded of this ComputedUsage.
        :rtype: str
        """
        return self._cost_rounded

    @cost_rounded.setter
    def cost_rounded(self, cost_rounded):
        """
        Sets the cost_rounded of this ComputedUsage.
        Computed Line Amount rounded.


        :param cost_rounded: The cost_rounded of this ComputedUsage.
        :type: str
        """
        self._cost_rounded = cost_rounded

    @property
    def cost(self):
        """
        Gets the cost of this ComputedUsage.
        Computed Line Amount not rounded


        :return: The cost of this ComputedUsage.
        :rtype: str
        """
        return self._cost

    @cost.setter
    def cost(self, cost):
        """
        Sets the cost of this ComputedUsage.
        Computed Line Amount not rounded


        :param cost: The cost of this ComputedUsage.
        :type: str
        """
        self._cost = cost

    @property
    def product(self):
        """
        Gets the product of this ComputedUsage.

        :return: The product of this ComputedUsage.
        :rtype: oci.osub_usage.models.Product
        """
        return self._product

    @product.setter
    def product(self, product):
        """
        Sets the product of this ComputedUsage.

        :param product: The product of this ComputedUsage.
        :type: oci.osub_usage.models.Product
        """
        self._product = product

    @property
    def unit_of_measure(self):
        """
        Gets the unit_of_measure of this ComputedUsage.
        Unit of Messure


        :return: The unit_of_measure of this ComputedUsage.
        :rtype: str
        """
        return self._unit_of_measure

    @unit_of_measure.setter
    def unit_of_measure(self, unit_of_measure):
        """
        Sets the unit_of_measure of this ComputedUsage.
        Unit of Messure


        :param unit_of_measure: The unit_of_measure of this ComputedUsage.
        :type: str
        """
        self._unit_of_measure = unit_of_measure

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AnalyzeImageResult(object):
    """
    The image analysis results.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AnalyzeImageResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param image_objects:
            The value to assign to the image_objects property of this AnalyzeImageResult.
        :type image_objects: list[oci.ai_vision.models.ImageObject]

        :param labels:
            The value to assign to the labels property of this AnalyzeImageResult.
        :type labels: list[oci.ai_vision.models.Label]

        :param ontology_classes:
            The value to assign to the ontology_classes property of this AnalyzeImageResult.
        :type ontology_classes: list[oci.ai_vision.models.OntologyClass]

        :param image_text:
            The value to assign to the image_text property of this AnalyzeImageResult.
        :type image_text: oci.ai_vision.models.ImageText

        :param image_classification_model_version:
            The value to assign to the image_classification_model_version property of this AnalyzeImageResult.
        :type image_classification_model_version: str

        :param object_detection_model_version:
            The value to assign to the object_detection_model_version property of this AnalyzeImageResult.
        :type object_detection_model_version: str

        :param text_detection_model_version:
            The value to assign to the text_detection_model_version property of this AnalyzeImageResult.
        :type text_detection_model_version: str

        :param errors:
            The value to assign to the errors property of this AnalyzeImageResult.
        :type errors: list[oci.ai_vision.models.ProcessingError]

        """
        self.swagger_types = {
            'image_objects': 'list[ImageObject]',
            'labels': 'list[Label]',
            'ontology_classes': 'list[OntologyClass]',
            'image_text': 'ImageText',
            'image_classification_model_version': 'str',
            'object_detection_model_version': 'str',
            'text_detection_model_version': 'str',
            'errors': 'list[ProcessingError]'
        }

        self.attribute_map = {
            'image_objects': 'imageObjects',
            'labels': 'labels',
            'ontology_classes': 'ontologyClasses',
            'image_text': 'imageText',
            'image_classification_model_version': 'imageClassificationModelVersion',
            'object_detection_model_version': 'objectDetectionModelVersion',
            'text_detection_model_version': 'textDetectionModelVersion',
            'errors': 'errors'
        }

        self._image_objects = None
        self._labels = None
        self._ontology_classes = None
        self._image_text = None
        self._image_classification_model_version = None
        self._object_detection_model_version = None
        self._text_detection_model_version = None
        self._errors = None

    @property
    def image_objects(self):
        """
        Gets the image_objects of this AnalyzeImageResult.
        The detected objects.


        :return: The image_objects of this AnalyzeImageResult.
        :rtype: list[oci.ai_vision.models.ImageObject]
        """
        return self._image_objects

    @image_objects.setter
    def image_objects(self, image_objects):
        """
        Sets the image_objects of this AnalyzeImageResult.
        The detected objects.


        :param image_objects: The image_objects of this AnalyzeImageResult.
        :type: list[oci.ai_vision.models.ImageObject]
        """
        self._image_objects = image_objects

    @property
    def labels(self):
        """
        Gets the labels of this AnalyzeImageResult.
        The image classification labels.


        :return: The labels of this AnalyzeImageResult.
        :rtype: list[oci.ai_vision.models.Label]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """
        Sets the labels of this AnalyzeImageResult.
        The image classification labels.


        :param labels: The labels of this AnalyzeImageResult.
        :type: list[oci.ai_vision.models.Label]
        """
        self._labels = labels

    @property
    def ontology_classes(self):
        """
        Gets the ontology_classes of this AnalyzeImageResult.
        The ontologyClasses of image labels.


        :return: The ontology_classes of this AnalyzeImageResult.
        :rtype: list[oci.ai_vision.models.OntologyClass]
        """
        return self._ontology_classes

    @ontology_classes.setter
    def ontology_classes(self, ontology_classes):
        """
        Sets the ontology_classes of this AnalyzeImageResult.
        The ontologyClasses of image labels.


        :param ontology_classes: The ontology_classes of this AnalyzeImageResult.
        :type: list[oci.ai_vision.models.OntologyClass]
        """
        self._ontology_classes = ontology_classes

    @property
    def image_text(self):
        """
        Gets the image_text of this AnalyzeImageResult.

        :return: The image_text of this AnalyzeImageResult.
        :rtype: oci.ai_vision.models.ImageText
        """
        return self._image_text

    @image_text.setter
    def image_text(self, image_text):
        """
        Sets the image_text of this AnalyzeImageResult.

        :param image_text: The image_text of this AnalyzeImageResult.
        :type: oci.ai_vision.models.ImageText
        """
        self._image_text = image_text

    @property
    def image_classification_model_version(self):
        """
        Gets the image_classification_model_version of this AnalyzeImageResult.
        The image classification model version.


        :return: The image_classification_model_version of this AnalyzeImageResult.
        :rtype: str
        """
        return self._image_classification_model_version

    @image_classification_model_version.setter
    def image_classification_model_version(self, image_classification_model_version):
        """
        Sets the image_classification_model_version of this AnalyzeImageResult.
        The image classification model version.


        :param image_classification_model_version: The image_classification_model_version of this AnalyzeImageResult.
        :type: str
        """
        self._image_classification_model_version = image_classification_model_version

    @property
    def object_detection_model_version(self):
        """
        Gets the object_detection_model_version of this AnalyzeImageResult.
        The object detection model version.


        :return: The object_detection_model_version of this AnalyzeImageResult.
        :rtype: str
        """
        return self._object_detection_model_version

    @object_detection_model_version.setter
    def object_detection_model_version(self, object_detection_model_version):
        """
        Sets the object_detection_model_version of this AnalyzeImageResult.
        The object detection model version.


        :param object_detection_model_version: The object_detection_model_version of this AnalyzeImageResult.
        :type: str
        """
        self._object_detection_model_version = object_detection_model_version

    @property
    def text_detection_model_version(self):
        """
        Gets the text_detection_model_version of this AnalyzeImageResult.
        The text detection model version.


        :return: The text_detection_model_version of this AnalyzeImageResult.
        :rtype: str
        """
        return self._text_detection_model_version

    @text_detection_model_version.setter
    def text_detection_model_version(self, text_detection_model_version):
        """
        Sets the text_detection_model_version of this AnalyzeImageResult.
        The text detection model version.


        :param text_detection_model_version: The text_detection_model_version of this AnalyzeImageResult.
        :type: str
        """
        self._text_detection_model_version = text_detection_model_version

    @property
    def errors(self):
        """
        Gets the errors of this AnalyzeImageResult.
        The errors encountered during image analysis.


        :return: The errors of this AnalyzeImageResult.
        :rtype: list[oci.ai_vision.models.ProcessingError]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """
        Sets the errors of this AnalyzeImageResult.
        The errors encountered during image analysis.


        :param errors: The errors of this AnalyzeImageResult.
        :type: list[oci.ai_vision.models.ProcessingError]
        """
        self._errors = errors

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DataPreview(object):
    """
    The data preview response.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DataPreview object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_name:
            The value to assign to the entity_name property of this DataPreview.
        :type entity_name: str

        :param sample_rows_count:
            The value to assign to the sample_rows_count property of this DataPreview.
        :type sample_rows_count: int

        :param columns:
            The value to assign to the columns property of this DataPreview.
        :type columns: list[oci.data_connectivity.models.Column]

        :param rows:
            The value to assign to the rows property of this DataPreview.
        :type rows: list[oci.data_connectivity.models.Row]

        """
        self.swagger_types = {
            'entity_name': 'str',
            'sample_rows_count': 'int',
            'columns': 'list[Column]',
            'rows': 'list[Row]'
        }

        self.attribute_map = {
            'entity_name': 'entityName',
            'sample_rows_count': 'sampleRowsCount',
            'columns': 'columns',
            'rows': 'rows'
        }

        self._entity_name = None
        self._sample_rows_count = None
        self._columns = None
        self._rows = None

    @property
    def entity_name(self):
        """
        **[Required]** Gets the entity_name of this DataPreview.
        Name of the entity for which data preview was requested


        :return: The entity_name of this DataPreview.
        :rtype: str
        """
        return self._entity_name

    @entity_name.setter
    def entity_name(self, entity_name):
        """
        Sets the entity_name of this DataPreview.
        Name of the entity for which data preview was requested


        :param entity_name: The entity_name of this DataPreview.
        :type: str
        """
        self._entity_name = entity_name

    @property
    def sample_rows_count(self):
        """
        Gets the sample_rows_count of this DataPreview.
        Total number of rows taken for sampling


        :return: The sample_rows_count of this DataPreview.
        :rtype: int
        """
        return self._sample_rows_count

    @sample_rows_count.setter
    def sample_rows_count(self, sample_rows_count):
        """
        Sets the sample_rows_count of this DataPreview.
        Total number of rows taken for sampling


        :param sample_rows_count: The sample_rows_count of this DataPreview.
        :type: int
        """
        self._sample_rows_count = sample_rows_count

    @property
    def columns(self):
        """
        Gets the columns of this DataPreview.
        Array of column definition for the preview result


        :return: The columns of this DataPreview.
        :rtype: list[oci.data_connectivity.models.Column]
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """
        Sets the columns of this DataPreview.
        Array of column definition for the preview result


        :param columns: The columns of this DataPreview.
        :type: list[oci.data_connectivity.models.Column]
        """
        self._columns = columns

    @property
    def rows(self):
        """
        Gets the rows of this DataPreview.
        Array of rows values for the preview result


        :return: The rows of this DataPreview.
        :rtype: list[oci.data_connectivity.models.Row]
        """
        return self._rows

    @rows.setter
    def rows(self, rows):
        """
        Sets the rows of this DataPreview.
        Array of rows values for the preview result


        :param rows: The rows of this DataPreview.
        :type: list[oci.data_connectivity.models.Row]
        """
        self._rows = rows

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DataAssetSummary(object):
    """
    The summary object for data asset.
    """

    #: A constant which can be used with the model_type property of a DataAssetSummary.
    #: This constant has a value of "ORACLE_DATA_ASSET"
    MODEL_TYPE_ORACLE_DATA_ASSET = "ORACLE_DATA_ASSET"

    #: A constant which can be used with the model_type property of a DataAssetSummary.
    #: This constant has a value of "ORACLE_OBJECT_STORAGE_DATA_ASSET"
    MODEL_TYPE_ORACLE_OBJECT_STORAGE_DATA_ASSET = "ORACLE_OBJECT_STORAGE_DATA_ASSET"

    #: A constant which can be used with the model_type property of a DataAssetSummary.
    #: This constant has a value of "ORACLE_ATP_DATA_ASSET"
    MODEL_TYPE_ORACLE_ATP_DATA_ASSET = "ORACLE_ATP_DATA_ASSET"

    #: A constant which can be used with the model_type property of a DataAssetSummary.
    #: This constant has a value of "ORACLE_ADWC_DATA_ASSET"
    MODEL_TYPE_ORACLE_ADWC_DATA_ASSET = "ORACLE_ADWC_DATA_ASSET"

    #: A constant which can be used with the model_type property of a DataAssetSummary.
    #: This constant has a value of "MYSQL_DATA_ASSET"
    MODEL_TYPE_MYSQL_DATA_ASSET = "MYSQL_DATA_ASSET"

    #: A constant which can be used with the model_type property of a DataAssetSummary.
    #: This constant has a value of "GENERIC_JDBC_DATA_ASSET"
    MODEL_TYPE_GENERIC_JDBC_DATA_ASSET = "GENERIC_JDBC_DATA_ASSET"

    #: A constant which can be used with the model_type property of a DataAssetSummary.
    #: This constant has a value of "FUSION_APP_DATA_ASSET"
    MODEL_TYPE_FUSION_APP_DATA_ASSET = "FUSION_APP_DATA_ASSET"

    #: A constant which can be used with the model_type property of a DataAssetSummary.
    #: This constant has a value of "AMAZON_S3_DATA_ASSET"
    MODEL_TYPE_AMAZON_S3_DATA_ASSET = "AMAZON_S3_DATA_ASSET"

    def __init__(self, **kwargs):
        """
        Initializes a new DataAssetSummary object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.data_integration.models.DataAssetSummaryFromMySQL`
        * :class:`~oci.data_integration.models.DataAssetSummaryFromAtp`
        * :class:`~oci.data_integration.models.DataAssetSummaryFromAdwc`
        * :class:`~oci.data_integration.models.DataAssetSummaryFromJdbc`
        * :class:`~oci.data_integration.models.DataAssetSummaryFromAmazonS3`
        * :class:`~oci.data_integration.models.DataAssetSummaryFromObjectStorage`
        * :class:`~oci.data_integration.models.DataAssetSummaryFromOracle`
        * :class:`~oci.data_integration.models.DataAssetSummaryFromFusionApp`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this DataAssetSummary.
            Allowed values for this property are: "ORACLE_DATA_ASSET", "ORACLE_OBJECT_STORAGE_DATA_ASSET", "ORACLE_ATP_DATA_ASSET", "ORACLE_ADWC_DATA_ASSET", "MYSQL_DATA_ASSET", "GENERIC_JDBC_DATA_ASSET", "FUSION_APP_DATA_ASSET", "AMAZON_S3_DATA_ASSET", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param key:
            The value to assign to the key property of this DataAssetSummary.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this DataAssetSummary.
        :type model_version: str

        :param name:
            The value to assign to the name property of this DataAssetSummary.
        :type name: str

        :param description:
            The value to assign to the description property of this DataAssetSummary.
        :type description: str

        :param object_status:
            The value to assign to the object_status property of this DataAssetSummary.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this DataAssetSummary.
        :type identifier: str

        :param external_key:
            The value to assign to the external_key property of this DataAssetSummary.
        :type external_key: str

        :param asset_properties:
            The value to assign to the asset_properties property of this DataAssetSummary.
        :type asset_properties: dict(str, str)

        :param native_type_system:
            The value to assign to the native_type_system property of this DataAssetSummary.
        :type native_type_system: oci.data_integration.models.TypeSystem

        :param object_version:
            The value to assign to the object_version property of this DataAssetSummary.
        :type object_version: int

        :param parent_ref:
            The value to assign to the parent_ref property of this DataAssetSummary.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param metadata:
            The value to assign to the metadata property of this DataAssetSummary.
        :type metadata: oci.data_integration.models.ObjectMetadata

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'name': 'str',
            'description': 'str',
            'object_status': 'int',
            'identifier': 'str',
            'external_key': 'str',
            'asset_properties': 'dict(str, str)',
            'native_type_system': 'TypeSystem',
            'object_version': 'int',
            'parent_ref': 'ParentReference',
            'metadata': 'ObjectMetadata'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'name': 'name',
            'description': 'description',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'external_key': 'externalKey',
            'asset_properties': 'assetProperties',
            'native_type_system': 'nativeTypeSystem',
            'object_version': 'objectVersion',
            'parent_ref': 'parentRef',
            'metadata': 'metadata'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._name = None
        self._description = None
        self._object_status = None
        self._identifier = None
        self._external_key = None
        self._asset_properties = None
        self._native_type_system = None
        self._object_version = None
        self._parent_ref = None
        self._metadata = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['modelType']

        if type == 'MYSQL_DATA_ASSET':
            return 'DataAssetSummaryFromMySQL'

        if type == 'ORACLE_ATP_DATA_ASSET':
            return 'DataAssetSummaryFromAtp'

        if type == 'ORACLE_ADWC_DATA_ASSET':
            return 'DataAssetSummaryFromAdwc'

        if type == 'GENERIC_JDBC_DATA_ASSET':
            return 'DataAssetSummaryFromJdbc'

        if type == 'AMAZON_S3_DATA_ASSET':
            return 'DataAssetSummaryFromAmazonS3'

        if type == 'ORACLE_OBJECT_STORAGE_DATA_ASSET':
            return 'DataAssetSummaryFromObjectStorage'

        if type == 'ORACLE_DATA_ASSET':
            return 'DataAssetSummaryFromOracle'

        if type == 'FUSION_APP_DATA_ASSET':
            return 'DataAssetSummaryFromFusionApp'
        else:
            return 'DataAssetSummary'

    @property
    def model_type(self):
        """
        Gets the model_type of this DataAssetSummary.
        The type of the data asset.

        Allowed values for this property are: "ORACLE_DATA_ASSET", "ORACLE_OBJECT_STORAGE_DATA_ASSET", "ORACLE_ATP_DATA_ASSET", "ORACLE_ADWC_DATA_ASSET", "MYSQL_DATA_ASSET", "GENERIC_JDBC_DATA_ASSET", "FUSION_APP_DATA_ASSET", "AMAZON_S3_DATA_ASSET", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The model_type of this DataAssetSummary.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this DataAssetSummary.
        The type of the data asset.


        :param model_type: The model_type of this DataAssetSummary.
        :type: str
        """
        allowed_values = ["ORACLE_DATA_ASSET", "ORACLE_OBJECT_STORAGE_DATA_ASSET", "ORACLE_ATP_DATA_ASSET", "ORACLE_ADWC_DATA_ASSET", "MYSQL_DATA_ASSET", "GENERIC_JDBC_DATA_ASSET", "FUSION_APP_DATA_ASSET", "AMAZON_S3_DATA_ASSET"]
        if not value_allowed_none_or_none_sentinel(model_type, allowed_values):
            model_type = 'UNKNOWN_ENUM_VALUE'
        self._model_type = model_type

    @property
    def key(self):
        """
        Gets the key of this DataAssetSummary.
        Generated key that can be used in API calls to identify data asset.


        :return: The key of this DataAssetSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this DataAssetSummary.
        Generated key that can be used in API calls to identify data asset.


        :param key: The key of this DataAssetSummary.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this DataAssetSummary.
        The model version of an object.


        :return: The model_version of this DataAssetSummary.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this DataAssetSummary.
        The model version of an object.


        :param model_version: The model_version of this DataAssetSummary.
        :type: str
        """
        self._model_version = model_version

    @property
    def name(self):
        """
        Gets the name of this DataAssetSummary.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this DataAssetSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DataAssetSummary.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this DataAssetSummary.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this DataAssetSummary.
        The user-defined description of the data asset.


        :return: The description of this DataAssetSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DataAssetSummary.
        The user-defined description of the data asset.


        :param description: The description of this DataAssetSummary.
        :type: str
        """
        self._description = description

    @property
    def object_status(self):
        """
        Gets the object_status of this DataAssetSummary.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this DataAssetSummary.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this DataAssetSummary.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this DataAssetSummary.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        Gets the identifier of this DataAssetSummary.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this DataAssetSummary.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this DataAssetSummary.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this DataAssetSummary.
        :type: str
        """
        self._identifier = identifier

    @property
    def external_key(self):
        """
        Gets the external_key of this DataAssetSummary.
        The external key for the object.


        :return: The external_key of this DataAssetSummary.
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """
        Sets the external_key of this DataAssetSummary.
        The external key for the object.


        :param external_key: The external_key of this DataAssetSummary.
        :type: str
        """
        self._external_key = external_key

    @property
    def asset_properties(self):
        """
        Gets the asset_properties of this DataAssetSummary.
        Additional properties for the data asset.


        :return: The asset_properties of this DataAssetSummary.
        :rtype: dict(str, str)
        """
        return self._asset_properties

    @asset_properties.setter
    def asset_properties(self, asset_properties):
        """
        Sets the asset_properties of this DataAssetSummary.
        Additional properties for the data asset.


        :param asset_properties: The asset_properties of this DataAssetSummary.
        :type: dict(str, str)
        """
        self._asset_properties = asset_properties

    @property
    def native_type_system(self):
        """
        Gets the native_type_system of this DataAssetSummary.

        :return: The native_type_system of this DataAssetSummary.
        :rtype: oci.data_integration.models.TypeSystem
        """
        return self._native_type_system

    @native_type_system.setter
    def native_type_system(self, native_type_system):
        """
        Sets the native_type_system of this DataAssetSummary.

        :param native_type_system: The native_type_system of this DataAssetSummary.
        :type: oci.data_integration.models.TypeSystem
        """
        self._native_type_system = native_type_system

    @property
    def object_version(self):
        """
        Gets the object_version of this DataAssetSummary.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this DataAssetSummary.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this DataAssetSummary.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this DataAssetSummary.
        :type: int
        """
        self._object_version = object_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this DataAssetSummary.

        :return: The parent_ref of this DataAssetSummary.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this DataAssetSummary.

        :param parent_ref: The parent_ref of this DataAssetSummary.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def metadata(self):
        """
        Gets the metadata of this DataAssetSummary.

        :return: The metadata of this DataAssetSummary.
        :rtype: oci.data_integration.models.ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this DataAssetSummary.

        :param metadata: The metadata of this DataAssetSummary.
        :type: oci.data_integration.models.ObjectMetadata
        """
        self._metadata = metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NoRouteRoutingActionDetails(object):
    """
    Defines the routing action taken on traffic flow with no route found.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new NoRouteRoutingActionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_restricted_or_partial:
            The value to assign to the is_restricted_or_partial property of this NoRouteRoutingActionDetails.
        :type is_restricted_or_partial: bool

        :param evaluated_vcn_route_table_id:
            The value to assign to the evaluated_vcn_route_table_id property of this NoRouteRoutingActionDetails.
        :type evaluated_vcn_route_table_id: str

        :param evaluated_drg_route_table_id:
            The value to assign to the evaluated_drg_route_table_id property of this NoRouteRoutingActionDetails.
        :type evaluated_drg_route_table_id: str

        """
        self.swagger_types = {
            'is_restricted_or_partial': 'bool',
            'evaluated_vcn_route_table_id': 'str',
            'evaluated_drg_route_table_id': 'str'
        }

        self.attribute_map = {
            'is_restricted_or_partial': 'isRestrictedOrPartial',
            'evaluated_vcn_route_table_id': 'evaluatedVcnRouteTableId',
            'evaluated_drg_route_table_id': 'evaluatedDrgRouteTableId'
        }

        self._is_restricted_or_partial = None
        self._evaluated_vcn_route_table_id = None
        self._evaluated_drg_route_table_id = None

    @property
    def is_restricted_or_partial(self):
        """
        **[Required]** Gets the is_restricted_or_partial of this NoRouteRoutingActionDetails.
        If true, the evaluated route table details are incomplete.


        :return: The is_restricted_or_partial of this NoRouteRoutingActionDetails.
        :rtype: bool
        """
        return self._is_restricted_or_partial

    @is_restricted_or_partial.setter
    def is_restricted_or_partial(self, is_restricted_or_partial):
        """
        Sets the is_restricted_or_partial of this NoRouteRoutingActionDetails.
        If true, the evaluated route table details are incomplete.


        :param is_restricted_or_partial: The is_restricted_or_partial of this NoRouteRoutingActionDetails.
        :type: bool
        """
        self._is_restricted_or_partial = is_restricted_or_partial

    @property
    def evaluated_vcn_route_table_id(self):
        """
        Gets the evaluated_vcn_route_table_id of this NoRouteRoutingActionDetails.
        `OCIDs`__ of the evaluated VCN route table.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The evaluated_vcn_route_table_id of this NoRouteRoutingActionDetails.
        :rtype: str
        """
        return self._evaluated_vcn_route_table_id

    @evaluated_vcn_route_table_id.setter
    def evaluated_vcn_route_table_id(self, evaluated_vcn_route_table_id):
        """
        Sets the evaluated_vcn_route_table_id of this NoRouteRoutingActionDetails.
        `OCIDs`__ of the evaluated VCN route table.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param evaluated_vcn_route_table_id: The evaluated_vcn_route_table_id of this NoRouteRoutingActionDetails.
        :type: str
        """
        self._evaluated_vcn_route_table_id = evaluated_vcn_route_table_id

    @property
    def evaluated_drg_route_table_id(self):
        """
        Gets the evaluated_drg_route_table_id of this NoRouteRoutingActionDetails.
        `OCIDs`__ of evaluated DRG route table.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The evaluated_drg_route_table_id of this NoRouteRoutingActionDetails.
        :rtype: str
        """
        return self._evaluated_drg_route_table_id

    @evaluated_drg_route_table_id.setter
    def evaluated_drg_route_table_id(self, evaluated_drg_route_table_id):
        """
        Sets the evaluated_drg_route_table_id of this NoRouteRoutingActionDetails.
        `OCIDs`__ of evaluated DRG route table.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param evaluated_drg_route_table_id: The evaluated_drg_route_table_id of this NoRouteRoutingActionDetails.
        :type: str
        """
        self._evaluated_drg_route_table_id = evaluated_drg_route_table_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .operator import Operator
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Split(Operator):
    """
    The information about the split operator. Split operator has one input and many output links. Split operator allows users to take one data set and based on conditions produce many different outputs.
    """

    #: A constant which can be used with the data_routing_strategy property of a Split.
    #: This constant has a value of "FIRST"
    DATA_ROUTING_STRATEGY_FIRST = "FIRST"

    #: A constant which can be used with the data_routing_strategy property of a Split.
    #: This constant has a value of "ALL"
    DATA_ROUTING_STRATEGY_ALL = "ALL"

    def __init__(self, **kwargs):
        """
        Initializes a new Split object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.Split.model_type` attribute
        of this class is ``SPLIT_OPERATOR`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this Split.
            Allowed values for this property are: "SOURCE_OPERATOR", "FILTER_OPERATOR", "JOINER_OPERATOR", "AGGREGATOR_OPERATOR", "PROJECTION_OPERATOR", "TARGET_OPERATOR", "FLATTEN_OPERATOR", "DISTINCT_OPERATOR", "SORT_OPERATOR", "UNION_OPERATOR", "INTERSECT_OPERATOR", "MINUS_OPERATOR", "MERGE_OPERATOR", "FUNCTION_OPERATOR", "SPLIT_OPERATOR", "START_OPERATOR", "END_OPERATOR", "PIPELINE_OPERATOR", "TASK_OPERATOR", "EXPRESSION_OPERATOR", "LOOKUP_OPERATOR", "PIVOT_OPERATOR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param key:
            The value to assign to the key property of this Split.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this Split.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this Split.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this Split.
        :type name: str

        :param description:
            The value to assign to the description property of this Split.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this Split.
        :type object_version: int

        :param input_ports:
            The value to assign to the input_ports property of this Split.
        :type input_ports: list[oci.data_integration.models.InputPort]

        :param output_ports:
            The value to assign to the output_ports property of this Split.
        :type output_ports: list[oci.data_integration.models.TypedObject]

        :param object_status:
            The value to assign to the object_status property of this Split.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this Split.
        :type identifier: str

        :param parameters:
            The value to assign to the parameters property of this Split.
        :type parameters: list[oci.data_integration.models.Parameter]

        :param op_config_values:
            The value to assign to the op_config_values property of this Split.
        :type op_config_values: oci.data_integration.models.ConfigValues

        :param data_routing_strategy:
            The value to assign to the data_routing_strategy property of this Split.
            Allowed values for this property are: "FIRST", "ALL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type data_routing_strategy: str

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'input_ports': 'list[InputPort]',
            'output_ports': 'list[TypedObject]',
            'object_status': 'int',
            'identifier': 'str',
            'parameters': 'list[Parameter]',
            'op_config_values': 'ConfigValues',
            'data_routing_strategy': 'str'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'input_ports': 'inputPorts',
            'output_ports': 'outputPorts',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'parameters': 'parameters',
            'op_config_values': 'opConfigValues',
            'data_routing_strategy': 'dataRoutingStrategy'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_version = None
        self._input_ports = None
        self._output_ports = None
        self._object_status = None
        self._identifier = None
        self._parameters = None
        self._op_config_values = None
        self._data_routing_strategy = None
        self._model_type = 'SPLIT_OPERATOR'

    @property
    def data_routing_strategy(self):
        """
        Gets the data_routing_strategy of this Split.
        Specify how to handle data that matches a split condition. Either data that matches the first condition should be removed from further processing by other conditions, or all matched data should be evaluated for all conditions.

        Allowed values for this property are: "FIRST", "ALL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The data_routing_strategy of this Split.
        :rtype: str
        """
        return self._data_routing_strategy

    @data_routing_strategy.setter
    def data_routing_strategy(self, data_routing_strategy):
        """
        Sets the data_routing_strategy of this Split.
        Specify how to handle data that matches a split condition. Either data that matches the first condition should be removed from further processing by other conditions, or all matched data should be evaluated for all conditions.


        :param data_routing_strategy: The data_routing_strategy of this Split.
        :type: str
        """
        allowed_values = ["FIRST", "ALL"]
        if not value_allowed_none_or_none_sentinel(data_routing_strategy, allowed_values):
            data_routing_strategy = 'UNKNOWN_ENUM_VALUE'
        self._data_routing_strategy = data_routing_strategy

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .instance_agent_command_source_details import InstanceAgentCommandSourceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceAgentCommandSourceViaTextDetails(InstanceAgentCommandSourceDetails):
    """
    The source of the command when provided using plain text.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceAgentCommandSourceViaTextDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.compute_instance_agent.models.InstanceAgentCommandSourceViaTextDetails.source_type` attribute
        of this class is ``TEXT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source_type:
            The value to assign to the source_type property of this InstanceAgentCommandSourceViaTextDetails.
            Allowed values for this property are: "TEXT", "OBJECT_STORAGE_URI", "OBJECT_STORAGE_TUPLE"
        :type source_type: str

        :param text:
            The value to assign to the text property of this InstanceAgentCommandSourceViaTextDetails.
        :type text: str

        :param text_sha256:
            The value to assign to the text_sha256 property of this InstanceAgentCommandSourceViaTextDetails.
        :type text_sha256: str

        """
        self.swagger_types = {
            'source_type': 'str',
            'text': 'str',
            'text_sha256': 'str'
        }

        self.attribute_map = {
            'source_type': 'sourceType',
            'text': 'text',
            'text_sha256': 'textSha256'
        }

        self._source_type = None
        self._text = None
        self._text_sha256 = None
        self._source_type = 'TEXT'

    @property
    def text(self):
        """
        **[Required]** Gets the text of this InstanceAgentCommandSourceViaTextDetails.
        The plain text command.


        :return: The text of this InstanceAgentCommandSourceViaTextDetails.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this InstanceAgentCommandSourceViaTextDetails.
        The plain text command.


        :param text: The text of this InstanceAgentCommandSourceViaTextDetails.
        :type: str
        """
        self._text = text

    @property
    def text_sha256(self):
        """
        Gets the text_sha256 of this InstanceAgentCommandSourceViaTextDetails.
        SHA-256 checksum value of the text content.


        :return: The text_sha256 of this InstanceAgentCommandSourceViaTextDetails.
        :rtype: str
        """
        return self._text_sha256

    @text_sha256.setter
    def text_sha256(self, text_sha256):
        """
        Sets the text_sha256 of this InstanceAgentCommandSourceViaTextDetails.
        SHA-256 checksum value of the text content.


        :param text_sha256: The text_sha256 of this InstanceAgentCommandSourceViaTextDetails.
        :type: str
        """
        self._text_sha256 = text_sha256

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateMaskingColumnDetails(object):
    """
    Details to create a new masking column. You can use this to add a parent column only.
    It automatically adds the child columns from the associated sensitive data model or
    target database. If you provide the sensitiveTypeId attribute but not the maskingFormats
    attribute, it automatically assigns the default masking format associated with the
    specified sensitive type. Alternatively, if you provide the maskingFormats attribute,
    the specified masking formats are assigned to the column.

    Using the maskingFormats attribute, you can assign one or more masking formats to a
    column. You can specify a condition as part of each masking format. It enables you
    to do <a href=\"https://docs.oracle.com/en/cloud/paas/data-safe/udscs/conditional-masking.html\">conditional masking</a>
    so that you can mask the column data values differently using different masking formats
    and the associated conditions. A masking format can have one or more format entries.
    The combined output of all the format entries is used for masking. It provides the
    flexibility to define a masking format that can generate different parts of a data
    value separately and then combine them to get the final data value for masking.

    You can use the maskingColumnGroup attribute to group the columns that you would like
    to mask together. It enables you to do
    <a href=\"https://docs.oracle.com/en/cloud/paas/data-safe/udscs/group-masking1.html#GUID-755056B9-9540-48C0-9491-262A44A85037\">group or compound masking</a>
    that ensures that the masked data across the columns in a group continue to retain
    the same logical relationship.
    """

    #: A constant which can be used with the object_type property of a CreateMaskingColumnDetails.
    #: This constant has a value of "TABLE"
    OBJECT_TYPE_TABLE = "TABLE"

    #: A constant which can be used with the object_type property of a CreateMaskingColumnDetails.
    #: This constant has a value of "EDITIONING_VIEW"
    OBJECT_TYPE_EDITIONING_VIEW = "EDITIONING_VIEW"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateMaskingColumnDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param schema_name:
            The value to assign to the schema_name property of this CreateMaskingColumnDetails.
        :type schema_name: str

        :param object_name:
            The value to assign to the object_name property of this CreateMaskingColumnDetails.
        :type object_name: str

        :param object_type:
            The value to assign to the object_type property of this CreateMaskingColumnDetails.
            Allowed values for this property are: "TABLE", "EDITIONING_VIEW"
        :type object_type: str

        :param column_name:
            The value to assign to the column_name property of this CreateMaskingColumnDetails.
        :type column_name: str

        :param masking_column_group:
            The value to assign to the masking_column_group property of this CreateMaskingColumnDetails.
        :type masking_column_group: str

        :param sensitive_type_id:
            The value to assign to the sensitive_type_id property of this CreateMaskingColumnDetails.
        :type sensitive_type_id: str

        :param is_masking_enabled:
            The value to assign to the is_masking_enabled property of this CreateMaskingColumnDetails.
        :type is_masking_enabled: bool

        :param masking_formats:
            The value to assign to the masking_formats property of this CreateMaskingColumnDetails.
        :type masking_formats: list[oci.data_safe.models.MaskingFormat]

        """
        self.swagger_types = {
            'schema_name': 'str',
            'object_name': 'str',
            'object_type': 'str',
            'column_name': 'str',
            'masking_column_group': 'str',
            'sensitive_type_id': 'str',
            'is_masking_enabled': 'bool',
            'masking_formats': 'list[MaskingFormat]'
        }

        self.attribute_map = {
            'schema_name': 'schemaName',
            'object_name': 'objectName',
            'object_type': 'objectType',
            'column_name': 'columnName',
            'masking_column_group': 'maskingColumnGroup',
            'sensitive_type_id': 'sensitiveTypeId',
            'is_masking_enabled': 'isMaskingEnabled',
            'masking_formats': 'maskingFormats'
        }

        self._schema_name = None
        self._object_name = None
        self._object_type = None
        self._column_name = None
        self._masking_column_group = None
        self._sensitive_type_id = None
        self._is_masking_enabled = None
        self._masking_formats = None

    @property
    def schema_name(self):
        """
        **[Required]** Gets the schema_name of this CreateMaskingColumnDetails.
        The name of the schema that contains the database column. This attribute cannot be updated for an existing masking column.


        :return: The schema_name of this CreateMaskingColumnDetails.
        :rtype: str
        """
        return self._schema_name

    @schema_name.setter
    def schema_name(self, schema_name):
        """
        Sets the schema_name of this CreateMaskingColumnDetails.
        The name of the schema that contains the database column. This attribute cannot be updated for an existing masking column.


        :param schema_name: The schema_name of this CreateMaskingColumnDetails.
        :type: str
        """
        self._schema_name = schema_name

    @property
    def object_name(self):
        """
        **[Required]** Gets the object_name of this CreateMaskingColumnDetails.
        The name of the object (table or editioning view) that contains the database column. This attribute cannot be updated for an existing masking column.


        :return: The object_name of this CreateMaskingColumnDetails.
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """
        Sets the object_name of this CreateMaskingColumnDetails.
        The name of the object (table or editioning view) that contains the database column. This attribute cannot be updated for an existing masking column.


        :param object_name: The object_name of this CreateMaskingColumnDetails.
        :type: str
        """
        self._object_name = object_name

    @property
    def object_type(self):
        """
        Gets the object_type of this CreateMaskingColumnDetails.
        The type of the object that contains the database column.

        Allowed values for this property are: "TABLE", "EDITIONING_VIEW"


        :return: The object_type of this CreateMaskingColumnDetails.
        :rtype: str
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """
        Sets the object_type of this CreateMaskingColumnDetails.
        The type of the object that contains the database column.


        :param object_type: The object_type of this CreateMaskingColumnDetails.
        :type: str
        """
        allowed_values = ["TABLE", "EDITIONING_VIEW"]
        if not value_allowed_none_or_none_sentinel(object_type, allowed_values):
            raise ValueError(
                "Invalid value for `object_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._object_type = object_type

    @property
    def column_name(self):
        """
        **[Required]** Gets the column_name of this CreateMaskingColumnDetails.
        The name of the database column. This attribute cannot be updated for an existing
         masking column. Note that the same name is used for the masking column. There
         is no separate displayName attribute for the masking column.


        :return: The column_name of this CreateMaskingColumnDetails.
        :rtype: str
        """
        return self._column_name

    @column_name.setter
    def column_name(self, column_name):
        """
        Sets the column_name of this CreateMaskingColumnDetails.
        The name of the database column. This attribute cannot be updated for an existing
         masking column. Note that the same name is used for the masking column. There
         is no separate displayName attribute for the masking column.


        :param column_name: The column_name of this CreateMaskingColumnDetails.
        :type: str
        """
        self._column_name = column_name

    @property
    def masking_column_group(self):
        """
        Gets the masking_column_group of this CreateMaskingColumnDetails.
        The group of the masking column. It's a masking group identifier and can be any string
        of acceptable length. All the columns in a group are masked together to ensure that
        the masked data across these columns continue to retain the same logical relationship.
        For more details, check
        <a href=https://docs.oracle.com/en/cloud/paas/data-safe/udscs/group-masking1.html#GUID-755056B9-9540-48C0-9491-262A44A85037>Group Masking in the Data Safe documentation.</a>


        :return: The masking_column_group of this CreateMaskingColumnDetails.
        :rtype: str
        """
        return self._masking_column_group

    @masking_column_group.setter
    def masking_column_group(self, masking_column_group):
        """
        Sets the masking_column_group of this CreateMaskingColumnDetails.
        The group of the masking column. It's a masking group identifier and can be any string
        of acceptable length. All the columns in a group are masked together to ensure that
        the masked data across these columns continue to retain the same logical relationship.
        For more details, check
        <a href=https://docs.oracle.com/en/cloud/paas/data-safe/udscs/group-masking1.html#GUID-755056B9-9540-48C0-9491-262A44A85037>Group Masking in the Data Safe documentation.</a>


        :param masking_column_group: The masking_column_group of this CreateMaskingColumnDetails.
        :type: str
        """
        self._masking_column_group = masking_column_group

    @property
    def sensitive_type_id(self):
        """
        Gets the sensitive_type_id of this CreateMaskingColumnDetails.
        The OCID of the sensitive type to be associated with the masking column. Note that
        if the maskingFormats attribute isn't provided while creating a masking column,
        the default masking format associated with the specified sensitive type is assigned
        to the masking column.


        :return: The sensitive_type_id of this CreateMaskingColumnDetails.
        :rtype: str
        """
        return self._sensitive_type_id

    @sensitive_type_id.setter
    def sensitive_type_id(self, sensitive_type_id):
        """
        Sets the sensitive_type_id of this CreateMaskingColumnDetails.
        The OCID of the sensitive type to be associated with the masking column. Note that
        if the maskingFormats attribute isn't provided while creating a masking column,
        the default masking format associated with the specified sensitive type is assigned
        to the masking column.


        :param sensitive_type_id: The sensitive_type_id of this CreateMaskingColumnDetails.
        :type: str
        """
        self._sensitive_type_id = sensitive_type_id

    @property
    def is_masking_enabled(self):
        """
        Gets the is_masking_enabled of this CreateMaskingColumnDetails.
        Indicates if data masking is enabled for the masking column. Set it to false if
        you don't want to mask the column.


        :return: The is_masking_enabled of this CreateMaskingColumnDetails.
        :rtype: bool
        """
        return self._is_masking_enabled

    @is_masking_enabled.setter
    def is_masking_enabled(self, is_masking_enabled):
        """
        Sets the is_masking_enabled of this CreateMaskingColumnDetails.
        Indicates if data masking is enabled for the masking column. Set it to false if
        you don't want to mask the column.


        :param is_masking_enabled: The is_masking_enabled of this CreateMaskingColumnDetails.
        :type: bool
        """
        self._is_masking_enabled = is_masking_enabled

    @property
    def masking_formats(self):
        """
        Gets the masking_formats of this CreateMaskingColumnDetails.
        The masking formats to be assigned to the masking column. You can specify a condition
        as part of each masking format. It enables you to do
        <a href=\"https://docs.oracle.com/en/cloud/paas/data-safe/udscs/conditional-masking.html\">conditional masking</a>
        so that you can mask the column data values differently using different masking
        formats and the associated conditions. A masking format can have one or more format
        entries. The combined output of all the format entries is used for masking. It
        provides the flexibility to define a masking format that can generate different parts
        of a data value separately and then combine them to get the final data value for masking.


        :return: The masking_formats of this CreateMaskingColumnDetails.
        :rtype: list[oci.data_safe.models.MaskingFormat]
        """
        return self._masking_formats

    @masking_formats.setter
    def masking_formats(self, masking_formats):
        """
        Sets the masking_formats of this CreateMaskingColumnDetails.
        The masking formats to be assigned to the masking column. You can specify a condition
        as part of each masking format. It enables you to do
        <a href=\"https://docs.oracle.com/en/cloud/paas/data-safe/udscs/conditional-masking.html\">conditional masking</a>
        so that you can mask the column data values differently using different masking
        formats and the associated conditions. A masking format can have one or more format
        entries. The combined output of all the format entries is used for masking. It
        provides the flexibility to define a masking format that can generate different parts
        of a data value separately and then combine them to get the final data value for masking.


        :param masking_formats: The masking_formats of this CreateMaskingColumnDetails.
        :type: list[oci.data_safe.models.MaskingFormat]
        """
        self._masking_formats = masking_formats

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ProxyUserSummary(object):
    """
    A summary of the proxy user.
    """

    #: A constant which can be used with the authentication property of a ProxyUserSummary.
    #: This constant has a value of "YES"
    AUTHENTICATION_YES = "YES"

    #: A constant which can be used with the authentication property of a ProxyUserSummary.
    #: This constant has a value of "NO"
    AUTHENTICATION_NO = "NO"

    #: A constant which can be used with the flags property of a ProxyUserSummary.
    #: This constant has a value of "PROXY_MAY_ACTIVATE_ALL_CLIENT_ROLES"
    FLAGS_PROXY_MAY_ACTIVATE_ALL_CLIENT_ROLES = "PROXY_MAY_ACTIVATE_ALL_CLIENT_ROLES"

    #: A constant which can be used with the flags property of a ProxyUserSummary.
    #: This constant has a value of "NO_CLIENT_ROLES_MAY_BE_ACTIVATED"
    FLAGS_NO_CLIENT_ROLES_MAY_BE_ACTIVATED = "NO_CLIENT_ROLES_MAY_BE_ACTIVATED"

    #: A constant which can be used with the flags property of a ProxyUserSummary.
    #: This constant has a value of "PROXY_MAY_ACTIVATE_ROLE"
    FLAGS_PROXY_MAY_ACTIVATE_ROLE = "PROXY_MAY_ACTIVATE_ROLE"

    #: A constant which can be used with the flags property of a ProxyUserSummary.
    #: This constant has a value of "PROXY_MAY_NOT_ACTIVATE_ROLE"
    FLAGS_PROXY_MAY_NOT_ACTIVATE_ROLE = "PROXY_MAY_NOT_ACTIVATE_ROLE"

    def __init__(self, **kwargs):
        """
        Initializes a new ProxyUserSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ProxyUserSummary.
        :type name: str

        :param authentication:
            The value to assign to the authentication property of this ProxyUserSummary.
            Allowed values for this property are: "YES", "NO", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type authentication: str

        :param flags:
            The value to assign to the flags property of this ProxyUserSummary.
            Allowed values for this property are: "PROXY_MAY_ACTIVATE_ALL_CLIENT_ROLES", "NO_CLIENT_ROLES_MAY_BE_ACTIVATED", "PROXY_MAY_ACTIVATE_ROLE", "PROXY_MAY_NOT_ACTIVATE_ROLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type flags: str

        """
        self.swagger_types = {
            'name': 'str',
            'authentication': 'str',
            'flags': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'authentication': 'authentication',
            'flags': 'flags'
        }

        self._name = None
        self._authentication = None
        self._flags = None

    @property
    def name(self):
        """
        Gets the name of this ProxyUserSummary.
        The name of a proxy user or the name of the client user.


        :return: The name of this ProxyUserSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ProxyUserSummary.
        The name of a proxy user or the name of the client user.


        :param name: The name of this ProxyUserSummary.
        :type: str
        """
        self._name = name

    @property
    def authentication(self):
        """
        Gets the authentication of this ProxyUserSummary.
        Indicates whether the proxy is required to supply the client credentials (YES) or not (NO).

        Allowed values for this property are: "YES", "NO", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The authentication of this ProxyUserSummary.
        :rtype: str
        """
        return self._authentication

    @authentication.setter
    def authentication(self, authentication):
        """
        Sets the authentication of this ProxyUserSummary.
        Indicates whether the proxy is required to supply the client credentials (YES) or not (NO).


        :param authentication: The authentication of this ProxyUserSummary.
        :type: str
        """
        allowed_values = ["YES", "NO"]
        if not value_allowed_none_or_none_sentinel(authentication, allowed_values):
            authentication = 'UNKNOWN_ENUM_VALUE'
        self._authentication = authentication

    @property
    def flags(self):
        """
        Gets the flags of this ProxyUserSummary.
        The flags associated with the proxy/client pair.

        Allowed values for this property are: "PROXY_MAY_ACTIVATE_ALL_CLIENT_ROLES", "NO_CLIENT_ROLES_MAY_BE_ACTIVATED", "PROXY_MAY_ACTIVATE_ROLE", "PROXY_MAY_NOT_ACTIVATE_ROLE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The flags of this ProxyUserSummary.
        :rtype: str
        """
        return self._flags

    @flags.setter
    def flags(self, flags):
        """
        Sets the flags of this ProxyUserSummary.
        The flags associated with the proxy/client pair.


        :param flags: The flags of this ProxyUserSummary.
        :type: str
        """
        allowed_values = ["PROXY_MAY_ACTIVATE_ALL_CLIENT_ROLES", "NO_CLIENT_ROLES_MAY_BE_ACTIVATED", "PROXY_MAY_ACTIVATE_ROLE", "PROXY_MAY_NOT_ACTIVATE_ROLE"]
        if not value_allowed_none_or_none_sentinel(flags, allowed_values):
            flags = 'UNKNOWN_ENUM_VALUE'
        self._flags = flags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SubscriptionSubscribedService(object):
    """
    Subscribed Service summary
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SubscriptionSubscribedService object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this SubscriptionSubscribedService.
        :type id: str

        :param product:
            The value to assign to the product property of this SubscriptionSubscribedService.
        :type product: oci.onesubscription.models.SubscriptionProduct

        :param quantity:
            The value to assign to the quantity property of this SubscriptionSubscribedService.
        :type quantity: str

        :param status:
            The value to assign to the status property of this SubscriptionSubscribedService.
        :type status: str

        :param operation_type:
            The value to assign to the operation_type property of this SubscriptionSubscribedService.
        :type operation_type: str

        :param net_unit_price:
            The value to assign to the net_unit_price property of this SubscriptionSubscribedService.
        :type net_unit_price: str

        :param used_amount:
            The value to assign to the used_amount property of this SubscriptionSubscribedService.
        :type used_amount: str

        :param available_amount:
            The value to assign to the available_amount property of this SubscriptionSubscribedService.
        :type available_amount: str

        :param funded_allocation_value:
            The value to assign to the funded_allocation_value property of this SubscriptionSubscribedService.
        :type funded_allocation_value: str

        :param partner_transaction_type:
            The value to assign to the partner_transaction_type property of this SubscriptionSubscribedService.
        :type partner_transaction_type: str

        :param term_value:
            The value to assign to the term_value property of this SubscriptionSubscribedService.
        :type term_value: int

        :param term_value_uom:
            The value to assign to the term_value_uom property of this SubscriptionSubscribedService.
        :type term_value_uom: str

        :param booking_opty_number:
            The value to assign to the booking_opty_number property of this SubscriptionSubscribedService.
        :type booking_opty_number: str

        :param total_value:
            The value to assign to the total_value property of this SubscriptionSubscribedService.
        :type total_value: str

        :param original_promo_amount:
            The value to assign to the original_promo_amount property of this SubscriptionSubscribedService.
        :type original_promo_amount: str

        :param order_number:
            The value to assign to the order_number property of this SubscriptionSubscribedService.
        :type order_number: int

        :param data_center_region:
            The value to assign to the data_center_region property of this SubscriptionSubscribedService.
        :type data_center_region: str

        :param pricing_model:
            The value to assign to the pricing_model property of this SubscriptionSubscribedService.
        :type pricing_model: str

        :param program_type:
            The value to assign to the program_type property of this SubscriptionSubscribedService.
        :type program_type: str

        :param promo_type:
            The value to assign to the promo_type property of this SubscriptionSubscribedService.
        :type promo_type: str

        :param csi:
            The value to assign to the csi property of this SubscriptionSubscribedService.
        :type csi: int

        :param is_intent_to_pay:
            The value to assign to the is_intent_to_pay property of this SubscriptionSubscribedService.
        :type is_intent_to_pay: bool

        :param time_start:
            The value to assign to the time_start property of this SubscriptionSubscribedService.
        :type time_start: datetime

        :param time_end:
            The value to assign to the time_end property of this SubscriptionSubscribedService.
        :type time_end: datetime

        :param commitment_services:
            The value to assign to the commitment_services property of this SubscriptionSubscribedService.
        :type commitment_services: list[oci.onesubscription.models.CommitmentService]

        """
        self.swagger_types = {
            'id': 'str',
            'product': 'SubscriptionProduct',
            'quantity': 'str',
            'status': 'str',
            'operation_type': 'str',
            'net_unit_price': 'str',
            'used_amount': 'str',
            'available_amount': 'str',
            'funded_allocation_value': 'str',
            'partner_transaction_type': 'str',
            'term_value': 'int',
            'term_value_uom': 'str',
            'booking_opty_number': 'str',
            'total_value': 'str',
            'original_promo_amount': 'str',
            'order_number': 'int',
            'data_center_region': 'str',
            'pricing_model': 'str',
            'program_type': 'str',
            'promo_type': 'str',
            'csi': 'int',
            'is_intent_to_pay': 'bool',
            'time_start': 'datetime',
            'time_end': 'datetime',
            'commitment_services': 'list[CommitmentService]'
        }

        self.attribute_map = {
            'id': 'id',
            'product': 'product',
            'quantity': 'quantity',
            'status': 'status',
            'operation_type': 'operationType',
            'net_unit_price': 'netUnitPrice',
            'used_amount': 'usedAmount',
            'available_amount': 'availableAmount',
            'funded_allocation_value': 'fundedAllocationValue',
            'partner_transaction_type': 'partnerTransactionType',
            'term_value': 'termValue',
            'term_value_uom': 'termValueUom',
            'booking_opty_number': 'bookingOptyNumber',
            'total_value': 'totalValue',
            'original_promo_amount': 'originalPromoAmount',
            'order_number': 'orderNumber',
            'data_center_region': 'dataCenterRegion',
            'pricing_model': 'pricingModel',
            'program_type': 'programType',
            'promo_type': 'promoType',
            'csi': 'csi',
            'is_intent_to_pay': 'isIntentToPay',
            'time_start': 'timeStart',
            'time_end': 'timeEnd',
            'commitment_services': 'commitmentServices'
        }

        self._id = None
        self._product = None
        self._quantity = None
        self._status = None
        self._operation_type = None
        self._net_unit_price = None
        self._used_amount = None
        self._available_amount = None
        self._funded_allocation_value = None
        self._partner_transaction_type = None
        self._term_value = None
        self._term_value_uom = None
        self._booking_opty_number = None
        self._total_value = None
        self._original_promo_amount = None
        self._order_number = None
        self._data_center_region = None
        self._pricing_model = None
        self._program_type = None
        self._promo_type = None
        self._csi = None
        self._is_intent_to_pay = None
        self._time_start = None
        self._time_end = None
        self._commitment_services = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this SubscriptionSubscribedService.
        SPM internal Subscribed Service ID


        :return: The id of this SubscriptionSubscribedService.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SubscriptionSubscribedService.
        SPM internal Subscribed Service ID


        :param id: The id of this SubscriptionSubscribedService.
        :type: str
        """
        self._id = id

    @property
    def product(self):
        """
        Gets the product of this SubscriptionSubscribedService.

        :return: The product of this SubscriptionSubscribedService.
        :rtype: oci.onesubscription.models.SubscriptionProduct
        """
        return self._product

    @product.setter
    def product(self, product):
        """
        Sets the product of this SubscriptionSubscribedService.

        :param product: The product of this SubscriptionSubscribedService.
        :type: oci.onesubscription.models.SubscriptionProduct
        """
        self._product = product

    @property
    def quantity(self):
        """
        Gets the quantity of this SubscriptionSubscribedService.
        Subscribed service quantity


        :return: The quantity of this SubscriptionSubscribedService.
        :rtype: str
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """
        Sets the quantity of this SubscriptionSubscribedService.
        Subscribed service quantity


        :param quantity: The quantity of this SubscriptionSubscribedService.
        :type: str
        """
        self._quantity = quantity

    @property
    def status(self):
        """
        Gets the status of this SubscriptionSubscribedService.
        Subscribed service status


        :return: The status of this SubscriptionSubscribedService.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this SubscriptionSubscribedService.
        Subscribed service status


        :param status: The status of this SubscriptionSubscribedService.
        :type: str
        """
        self._status = status

    @property
    def operation_type(self):
        """
        Gets the operation_type of this SubscriptionSubscribedService.
        Subscribed service operation type


        :return: The operation_type of this SubscriptionSubscribedService.
        :rtype: str
        """
        return self._operation_type

    @operation_type.setter
    def operation_type(self, operation_type):
        """
        Sets the operation_type of this SubscriptionSubscribedService.
        Subscribed service operation type


        :param operation_type: The operation_type of this SubscriptionSubscribedService.
        :type: str
        """
        self._operation_type = operation_type

    @property
    def net_unit_price(self):
        """
        Gets the net_unit_price of this SubscriptionSubscribedService.
        Subscribed service net unit price


        :return: The net_unit_price of this SubscriptionSubscribedService.
        :rtype: str
        """
        return self._net_unit_price

    @net_unit_price.setter
    def net_unit_price(self, net_unit_price):
        """
        Sets the net_unit_price of this SubscriptionSubscribedService.
        Subscribed service net unit price


        :param net_unit_price: The net_unit_price of this SubscriptionSubscribedService.
        :type: str
        """
        self._net_unit_price = net_unit_price

    @property
    def used_amount(self):
        """
        Gets the used_amount of this SubscriptionSubscribedService.
        Subscribed service used amount


        :return: The used_amount of this SubscriptionSubscribedService.
        :rtype: str
        """
        return self._used_amount

    @used_amount.setter
    def used_amount(self, used_amount):
        """
        Sets the used_amount of this SubscriptionSubscribedService.
        Subscribed service used amount


        :param used_amount: The used_amount of this SubscriptionSubscribedService.
        :type: str
        """
        self._used_amount = used_amount

    @property
    def available_amount(self):
        """
        Gets the available_amount of this SubscriptionSubscribedService.
        Subscribed sercice available or remaining amount


        :return: The available_amount of this SubscriptionSubscribedService.
        :rtype: str
        """
        return self._available_amount

    @available_amount.setter
    def available_amount(self, available_amount):
        """
        Sets the available_amount of this SubscriptionSubscribedService.
        Subscribed sercice available or remaining amount


        :param available_amount: The available_amount of this SubscriptionSubscribedService.
        :type: str
        """
        self._available_amount = available_amount

    @property
    def funded_allocation_value(self):
        """
        Gets the funded_allocation_value of this SubscriptionSubscribedService.
        Funded Allocation line value
        example: 12000.00


        :return: The funded_allocation_value of this SubscriptionSubscribedService.
        :rtype: str
        """
        return self._funded_allocation_value

    @funded_allocation_value.setter
    def funded_allocation_value(self, funded_allocation_value):
        """
        Sets the funded_allocation_value of this SubscriptionSubscribedService.
        Funded Allocation line value
        example: 12000.00


        :param funded_allocation_value: The funded_allocation_value of this SubscriptionSubscribedService.
        :type: str
        """
        self._funded_allocation_value = funded_allocation_value

    @property
    def partner_transaction_type(self):
        """
        Gets the partner_transaction_type of this SubscriptionSubscribedService.
        This field contains the name of the partner to which the subscription belongs - depending on which the invoicing may differ


        :return: The partner_transaction_type of this SubscriptionSubscribedService.
        :rtype: str
        """
        return self._partner_transaction_type

    @partner_transaction_type.setter
    def partner_transaction_type(self, partner_transaction_type):
        """
        Sets the partner_transaction_type of this SubscriptionSubscribedService.
        This field contains the name of the partner to which the subscription belongs - depending on which the invoicing may differ


        :param partner_transaction_type: The partner_transaction_type of this SubscriptionSubscribedService.
        :type: str
        """
        self._partner_transaction_type = partner_transaction_type

    @property
    def term_value(self):
        """
        Gets the term_value of this SubscriptionSubscribedService.
        Term value in Months


        :return: The term_value of this SubscriptionSubscribedService.
        :rtype: int
        """
        return self._term_value

    @term_value.setter
    def term_value(self, term_value):
        """
        Sets the term_value of this SubscriptionSubscribedService.
        Term value in Months


        :param term_value: The term_value of this SubscriptionSubscribedService.
        :type: int
        """
        self._term_value = term_value

    @property
    def term_value_uom(self):
        """
        Gets the term_value_uom of this SubscriptionSubscribedService.
        Term value UOM


        :return: The term_value_uom of this SubscriptionSubscribedService.
        :rtype: str
        """
        return self._term_value_uom

    @term_value_uom.setter
    def term_value_uom(self, term_value_uom):
        """
        Sets the term_value_uom of this SubscriptionSubscribedService.
        Term value UOM


        :param term_value_uom: The term_value_uom of this SubscriptionSubscribedService.
        :type: str
        """
        self._term_value_uom = term_value_uom

    @property
    def booking_opty_number(self):
        """
        Gets the booking_opty_number of this SubscriptionSubscribedService.
        Booking Opportunity Number of Subscribed Service


        :return: The booking_opty_number of this SubscriptionSubscribedService.
        :rtype: str
        """
        return self._booking_opty_number

    @booking_opty_number.setter
    def booking_opty_number(self, booking_opty_number):
        """
        Sets the booking_opty_number of this SubscriptionSubscribedService.
        Booking Opportunity Number of Subscribed Service


        :param booking_opty_number: The booking_opty_number of this SubscriptionSubscribedService.
        :type: str
        """
        self._booking_opty_number = booking_opty_number

    @property
    def total_value(self):
        """
        Gets the total_value of this SubscriptionSubscribedService.
        Subscribed service total value


        :return: The total_value of this SubscriptionSubscribedService.
        :rtype: str
        """
        return self._total_value

    @total_value.setter
    def total_value(self, total_value):
        """
        Sets the total_value of this SubscriptionSubscribedService.
        Subscribed service total value


        :param total_value: The total_value of this SubscriptionSubscribedService.
        :type: str
        """
        self._total_value = total_value

    @property
    def original_promo_amount(self):
        """
        Gets the original_promo_amount of this SubscriptionSubscribedService.
        Subscribed service Promotion Amount


        :return: The original_promo_amount of this SubscriptionSubscribedService.
        :rtype: str
        """
        return self._original_promo_amount

    @original_promo_amount.setter
    def original_promo_amount(self, original_promo_amount):
        """
        Sets the original_promo_amount of this SubscriptionSubscribedService.
        Subscribed service Promotion Amount


        :param original_promo_amount: The original_promo_amount of this SubscriptionSubscribedService.
        :type: str
        """
        self._original_promo_amount = original_promo_amount

    @property
    def order_number(self):
        """
        Gets the order_number of this SubscriptionSubscribedService.
        Sales Order Number associated to the subscribed service


        :return: The order_number of this SubscriptionSubscribedService.
        :rtype: int
        """
        return self._order_number

    @order_number.setter
    def order_number(self, order_number):
        """
        Sets the order_number of this SubscriptionSubscribedService.
        Sales Order Number associated to the subscribed service


        :param order_number: The order_number of this SubscriptionSubscribedService.
        :type: int
        """
        self._order_number = order_number

    @property
    def data_center_region(self):
        """
        Gets the data_center_region of this SubscriptionSubscribedService.
        Subscribed service data center region


        :return: The data_center_region of this SubscriptionSubscribedService.
        :rtype: str
        """
        return self._data_center_region

    @data_center_region.setter
    def data_center_region(self, data_center_region):
        """
        Sets the data_center_region of this SubscriptionSubscribedService.
        Subscribed service data center region


        :param data_center_region: The data_center_region of this SubscriptionSubscribedService.
        :type: str
        """
        self._data_center_region = data_center_region

    @property
    def pricing_model(self):
        """
        Gets the pricing_model of this SubscriptionSubscribedService.
        Subscribed service pricing model


        :return: The pricing_model of this SubscriptionSubscribedService.
        :rtype: str
        """
        return self._pricing_model

    @pricing_model.setter
    def pricing_model(self, pricing_model):
        """
        Sets the pricing_model of this SubscriptionSubscribedService.
        Subscribed service pricing model


        :param pricing_model: The pricing_model of this SubscriptionSubscribedService.
        :type: str
        """
        self._pricing_model = pricing_model

    @property
    def program_type(self):
        """
        Gets the program_type of this SubscriptionSubscribedService.
        Subscribed service program type


        :return: The program_type of this SubscriptionSubscribedService.
        :rtype: str
        """
        return self._program_type

    @program_type.setter
    def program_type(self, program_type):
        """
        Sets the program_type of this SubscriptionSubscribedService.
        Subscribed service program type


        :param program_type: The program_type of this SubscriptionSubscribedService.
        :type: str
        """
        self._program_type = program_type

    @property
    def promo_type(self):
        """
        Gets the promo_type of this SubscriptionSubscribedService.
        Subscribed service promotion type


        :return: The promo_type of this SubscriptionSubscribedService.
        :rtype: str
        """
        return self._promo_type

    @promo_type.setter
    def promo_type(self, promo_type):
        """
        Sets the promo_type of this SubscriptionSubscribedService.
        Subscribed service promotion type


        :param promo_type: The promo_type of this SubscriptionSubscribedService.
        :type: str
        """
        self._promo_type = promo_type

    @property
    def csi(self):
        """
        Gets the csi of this SubscriptionSubscribedService.
        Subscribed service CSI number


        :return: The csi of this SubscriptionSubscribedService.
        :rtype: int
        """
        return self._csi

    @csi.setter
    def csi(self, csi):
        """
        Sets the csi of this SubscriptionSubscribedService.
        Subscribed service CSI number


        :param csi: The csi of this SubscriptionSubscribedService.
        :type: int
        """
        self._csi = csi

    @property
    def is_intent_to_pay(self):
        """
        Gets the is_intent_to_pay of this SubscriptionSubscribedService.
        Subscribed service intent to pay flag


        :return: The is_intent_to_pay of this SubscriptionSubscribedService.
        :rtype: bool
        """
        return self._is_intent_to_pay

    @is_intent_to_pay.setter
    def is_intent_to_pay(self, is_intent_to_pay):
        """
        Sets the is_intent_to_pay of this SubscriptionSubscribedService.
        Subscribed service intent to pay flag


        :param is_intent_to_pay: The is_intent_to_pay of this SubscriptionSubscribedService.
        :type: bool
        """
        self._is_intent_to_pay = is_intent_to_pay

    @property
    def time_start(self):
        """
        Gets the time_start of this SubscriptionSubscribedService.
        Subscribed service start date


        :return: The time_start of this SubscriptionSubscribedService.
        :rtype: datetime
        """
        return self._time_start

    @time_start.setter
    def time_start(self, time_start):
        """
        Sets the time_start of this SubscriptionSubscribedService.
        Subscribed service start date


        :param time_start: The time_start of this SubscriptionSubscribedService.
        :type: datetime
        """
        self._time_start = time_start

    @property
    def time_end(self):
        """
        Gets the time_end of this SubscriptionSubscribedService.
        Subscribed service end date


        :return: The time_end of this SubscriptionSubscribedService.
        :rtype: datetime
        """
        return self._time_end

    @time_end.setter
    def time_end(self, time_end):
        """
        Sets the time_end of this SubscriptionSubscribedService.
        Subscribed service end date


        :param time_end: The time_end of this SubscriptionSubscribedService.
        :type: datetime
        """
        self._time_end = time_end

    @property
    def commitment_services(self):
        """
        Gets the commitment_services of this SubscriptionSubscribedService.
        List of Commitment services of a line


        :return: The commitment_services of this SubscriptionSubscribedService.
        :rtype: list[oci.onesubscription.models.CommitmentService]
        """
        return self._commitment_services

    @commitment_services.setter
    def commitment_services(self, commitment_services):
        """
        Sets the commitment_services of this SubscriptionSubscribedService.
        List of Commitment services of a line


        :param commitment_services: The commitment_services of this SubscriptionSubscribedService.
        :type: list[oci.onesubscription.models.CommitmentService]
        """
        self._commitment_services = commitment_services

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AddBlockStorageDetails(object):
    """
    The information about added block volumes.
    """

    #: A constant which can be used with the node_type property of a AddBlockStorageDetails.
    #: This constant has a value of "WORKER"
    NODE_TYPE_WORKER = "WORKER"

    #: A constant which can be used with the node_type property of a AddBlockStorageDetails.
    #: This constant has a value of "COMPUTE_ONLY_WORKER"
    NODE_TYPE_COMPUTE_ONLY_WORKER = "COMPUTE_ONLY_WORKER"

    def __init__(self, **kwargs):
        """
        Initializes a new AddBlockStorageDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cluster_admin_password:
            The value to assign to the cluster_admin_password property of this AddBlockStorageDetails.
        :type cluster_admin_password: str

        :param block_volume_size_in_gbs:
            The value to assign to the block_volume_size_in_gbs property of this AddBlockStorageDetails.
        :type block_volume_size_in_gbs: int

        :param node_type:
            The value to assign to the node_type property of this AddBlockStorageDetails.
            Allowed values for this property are: "WORKER", "COMPUTE_ONLY_WORKER"
        :type node_type: str

        """
        self.swagger_types = {
            'cluster_admin_password': 'str',
            'block_volume_size_in_gbs': 'int',
            'node_type': 'str'
        }

        self.attribute_map = {
            'cluster_admin_password': 'clusterAdminPassword',
            'block_volume_size_in_gbs': 'blockVolumeSizeInGBs',
            'node_type': 'nodeType'
        }

        self._cluster_admin_password = None
        self._block_volume_size_in_gbs = None
        self._node_type = None

    @property
    def cluster_admin_password(self):
        """
        **[Required]** Gets the cluster_admin_password of this AddBlockStorageDetails.
        Base-64 encoded password for the cluster (and Cloudera Manager) admin user.


        :return: The cluster_admin_password of this AddBlockStorageDetails.
        :rtype: str
        """
        return self._cluster_admin_password

    @cluster_admin_password.setter
    def cluster_admin_password(self, cluster_admin_password):
        """
        Sets the cluster_admin_password of this AddBlockStorageDetails.
        Base-64 encoded password for the cluster (and Cloudera Manager) admin user.


        :param cluster_admin_password: The cluster_admin_password of this AddBlockStorageDetails.
        :type: str
        """
        self._cluster_admin_password = cluster_admin_password

    @property
    def block_volume_size_in_gbs(self):
        """
        **[Required]** Gets the block_volume_size_in_gbs of this AddBlockStorageDetails.
        The size of block volume in GB to be added to each worker node. All the
        details needed for attaching the block volume are managed by service itself.


        :return: The block_volume_size_in_gbs of this AddBlockStorageDetails.
        :rtype: int
        """
        return self._block_volume_size_in_gbs

    @block_volume_size_in_gbs.setter
    def block_volume_size_in_gbs(self, block_volume_size_in_gbs):
        """
        Sets the block_volume_size_in_gbs of this AddBlockStorageDetails.
        The size of block volume in GB to be added to each worker node. All the
        details needed for attaching the block volume are managed by service itself.


        :param block_volume_size_in_gbs: The block_volume_size_in_gbs of this AddBlockStorageDetails.
        :type: int
        """
        self._block_volume_size_in_gbs = block_volume_size_in_gbs

    @property
    def node_type(self):
        """
        **[Required]** Gets the node_type of this AddBlockStorageDetails.
        Worker node types, can either be Worker Data node or Compute only worker node.

        Allowed values for this property are: "WORKER", "COMPUTE_ONLY_WORKER"


        :return: The node_type of this AddBlockStorageDetails.
        :rtype: str
        """
        return self._node_type

    @node_type.setter
    def node_type(self, node_type):
        """
        Sets the node_type of this AddBlockStorageDetails.
        Worker node types, can either be Worker Data node or Compute only worker node.


        :param node_type: The node_type of this AddBlockStorageDetails.
        :type: str
        """
        allowed_values = ["WORKER", "COMPUTE_ONLY_WORKER"]
        if not value_allowed_none_or_none_sentinel(node_type, allowed_values):
            raise ValueError(
                "Invalid value for `node_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._node_type = node_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDataGuardAssociationDetails(object):
    """
    The configuration details for creating a Data Guard association between databases.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    #: A constant which can be used with the protection_mode property of a CreateDataGuardAssociationDetails.
    #: This constant has a value of "MAXIMUM_AVAILABILITY"
    PROTECTION_MODE_MAXIMUM_AVAILABILITY = "MAXIMUM_AVAILABILITY"

    #: A constant which can be used with the protection_mode property of a CreateDataGuardAssociationDetails.
    #: This constant has a value of "MAXIMUM_PERFORMANCE"
    PROTECTION_MODE_MAXIMUM_PERFORMANCE = "MAXIMUM_PERFORMANCE"

    #: A constant which can be used with the protection_mode property of a CreateDataGuardAssociationDetails.
    #: This constant has a value of "MAXIMUM_PROTECTION"
    PROTECTION_MODE_MAXIMUM_PROTECTION = "MAXIMUM_PROTECTION"

    #: A constant which can be used with the transport_type property of a CreateDataGuardAssociationDetails.
    #: This constant has a value of "SYNC"
    TRANSPORT_TYPE_SYNC = "SYNC"

    #: A constant which can be used with the transport_type property of a CreateDataGuardAssociationDetails.
    #: This constant has a value of "ASYNC"
    TRANSPORT_TYPE_ASYNC = "ASYNC"

    #: A constant which can be used with the transport_type property of a CreateDataGuardAssociationDetails.
    #: This constant has a value of "FASTSYNC"
    TRANSPORT_TYPE_FASTSYNC = "FASTSYNC"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDataGuardAssociationDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.database.models.CreateDataGuardAssociationWithNewDbSystemDetails`
        * :class:`~oci.database.models.CreateDataGuardAssociationToExistingVmClusterDetails`
        * :class:`~oci.database.models.CreateDataGuardAssociationToExistingDbSystemDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param database_software_image_id:
            The value to assign to the database_software_image_id property of this CreateDataGuardAssociationDetails.
        :type database_software_image_id: str

        :param database_admin_password:
            The value to assign to the database_admin_password property of this CreateDataGuardAssociationDetails.
        :type database_admin_password: str

        :param protection_mode:
            The value to assign to the protection_mode property of this CreateDataGuardAssociationDetails.
            Allowed values for this property are: "MAXIMUM_AVAILABILITY", "MAXIMUM_PERFORMANCE", "MAXIMUM_PROTECTION"
        :type protection_mode: str

        :param transport_type:
            The value to assign to the transport_type property of this CreateDataGuardAssociationDetails.
            Allowed values for this property are: "SYNC", "ASYNC", "FASTSYNC"
        :type transport_type: str

        :param creation_type:
            The value to assign to the creation_type property of this CreateDataGuardAssociationDetails.
        :type creation_type: str

        :param is_active_data_guard_enabled:
            The value to assign to the is_active_data_guard_enabled property of this CreateDataGuardAssociationDetails.
        :type is_active_data_guard_enabled: bool

        :param peer_db_unique_name:
            The value to assign to the peer_db_unique_name property of this CreateDataGuardAssociationDetails.
        :type peer_db_unique_name: str

        :param peer_sid_prefix:
            The value to assign to the peer_sid_prefix property of this CreateDataGuardAssociationDetails.
        :type peer_sid_prefix: str

        """
        self.swagger_types = {
            'database_software_image_id': 'str',
            'database_admin_password': 'str',
            'protection_mode': 'str',
            'transport_type': 'str',
            'creation_type': 'str',
            'is_active_data_guard_enabled': 'bool',
            'peer_db_unique_name': 'str',
            'peer_sid_prefix': 'str'
        }

        self.attribute_map = {
            'database_software_image_id': 'databaseSoftwareImageId',
            'database_admin_password': 'databaseAdminPassword',
            'protection_mode': 'protectionMode',
            'transport_type': 'transportType',
            'creation_type': 'creationType',
            'is_active_data_guard_enabled': 'isActiveDataGuardEnabled',
            'peer_db_unique_name': 'peerDbUniqueName',
            'peer_sid_prefix': 'peerSidPrefix'
        }

        self._database_software_image_id = None
        self._database_admin_password = None
        self._protection_mode = None
        self._transport_type = None
        self._creation_type = None
        self._is_active_data_guard_enabled = None
        self._peer_db_unique_name = None
        self._peer_sid_prefix = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['creationType']

        if type == 'NewDbSystem':
            return 'CreateDataGuardAssociationWithNewDbSystemDetails'

        if type == 'ExistingVmCluster':
            return 'CreateDataGuardAssociationToExistingVmClusterDetails'

        if type == 'ExistingDbSystem':
            return 'CreateDataGuardAssociationToExistingDbSystemDetails'
        else:
            return 'CreateDataGuardAssociationDetails'

    @property
    def database_software_image_id(self):
        """
        Gets the database_software_image_id of this CreateDataGuardAssociationDetails.
        The database software image `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The database_software_image_id of this CreateDataGuardAssociationDetails.
        :rtype: str
        """
        return self._database_software_image_id

    @database_software_image_id.setter
    def database_software_image_id(self, database_software_image_id):
        """
        Sets the database_software_image_id of this CreateDataGuardAssociationDetails.
        The database software image `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param database_software_image_id: The database_software_image_id of this CreateDataGuardAssociationDetails.
        :type: str
        """
        self._database_software_image_id = database_software_image_id

    @property
    def database_admin_password(self):
        """
        **[Required]** Gets the database_admin_password of this CreateDataGuardAssociationDetails.
        A strong password for the `SYS`, `SYSTEM`, and `PDB Admin` users to apply during standby creation.

        The password must contain no fewer than nine characters and include:

        * At least two uppercase characters.

        * At least two lowercase characters.

        * At least two numeric characters.

        * At least two special characters. Valid special characters include \"_\", \"#\", and \"-\" only.

        **The password MUST be the same as the primary admin password.**


        :return: The database_admin_password of this CreateDataGuardAssociationDetails.
        :rtype: str
        """
        return self._database_admin_password

    @database_admin_password.setter
    def database_admin_password(self, database_admin_password):
        """
        Sets the database_admin_password of this CreateDataGuardAssociationDetails.
        A strong password for the `SYS`, `SYSTEM`, and `PDB Admin` users to apply during standby creation.

        The password must contain no fewer than nine characters and include:

        * At least two uppercase characters.

        * At least two lowercase characters.

        * At least two numeric characters.

        * At least two special characters. Valid special characters include \"_\", \"#\", and \"-\" only.

        **The password MUST be the same as the primary admin password.**


        :param database_admin_password: The database_admin_password of this CreateDataGuardAssociationDetails.
        :type: str
        """
        self._database_admin_password = database_admin_password

    @property
    def protection_mode(self):
        """
        **[Required]** Gets the protection_mode of this CreateDataGuardAssociationDetails.
        The protection mode to set up between the primary and standby databases. For more information, see
        `Oracle Data Guard Protection Modes`__
        in the Oracle Data Guard documentation.

        **IMPORTANT** - The only protection mode currently supported by the Database service is MAXIMUM_PERFORMANCE.

        __ http://docs.oracle.com/database/122/SBYDB/oracle-data-guard-protection-modes.htm#SBYDB02000

        Allowed values for this property are: "MAXIMUM_AVAILABILITY", "MAXIMUM_PERFORMANCE", "MAXIMUM_PROTECTION"


        :return: The protection_mode of this CreateDataGuardAssociationDetails.
        :rtype: str
        """
        return self._protection_mode

    @protection_mode.setter
    def protection_mode(self, protection_mode):
        """
        Sets the protection_mode of this CreateDataGuardAssociationDetails.
        The protection mode to set up between the primary and standby databases. For more information, see
        `Oracle Data Guard Protection Modes`__
        in the Oracle Data Guard documentation.

        **IMPORTANT** - The only protection mode currently supported by the Database service is MAXIMUM_PERFORMANCE.

        __ http://docs.oracle.com/database/122/SBYDB/oracle-data-guard-protection-modes.htm#SBYDB02000


        :param protection_mode: The protection_mode of this CreateDataGuardAssociationDetails.
        :type: str
        """
        allowed_values = ["MAXIMUM_AVAILABILITY", "MAXIMUM_PERFORMANCE", "MAXIMUM_PROTECTION"]
        if not value_allowed_none_or_none_sentinel(protection_mode, allowed_values):
            raise ValueError(
                "Invalid value for `protection_mode`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._protection_mode = protection_mode

    @property
    def transport_type(self):
        """
        **[Required]** Gets the transport_type of this CreateDataGuardAssociationDetails.
        The redo transport type to use for this Data Guard association.  Valid values depend on the specified `protectionMode`:

        * MAXIMUM_AVAILABILITY - SYNC or FASTSYNC
        * MAXIMUM_PERFORMANCE - ASYNC
        * MAXIMUM_PROTECTION - SYNC

        For more information, see
        `Redo Transport Services`__
        in the Oracle Data Guard documentation.

        **IMPORTANT** - The only transport type currently supported by the Database service is ASYNC.

        __ http://docs.oracle.com/database/122/SBYDB/oracle-data-guard-redo-transport-services.htm#SBYDB00400

        Allowed values for this property are: "SYNC", "ASYNC", "FASTSYNC"


        :return: The transport_type of this CreateDataGuardAssociationDetails.
        :rtype: str
        """
        return self._transport_type

    @transport_type.setter
    def transport_type(self, transport_type):
        """
        Sets the transport_type of this CreateDataGuardAssociationDetails.
        The redo transport type to use for this Data Guard association.  Valid values depend on the specified `protectionMode`:

        * MAXIMUM_AVAILABILITY - SYNC or FASTSYNC
        * MAXIMUM_PERFORMANCE - ASYNC
        * MAXIMUM_PROTECTION - SYNC

        For more information, see
        `Redo Transport Services`__
        in the Oracle Data Guard documentation.

        **IMPORTANT** - The only transport type currently supported by the Database service is ASYNC.

        __ http://docs.oracle.com/database/122/SBYDB/oracle-data-guard-redo-transport-services.htm#SBYDB00400


        :param transport_type: The transport_type of this CreateDataGuardAssociationDetails.
        :type: str
        """
        allowed_values = ["SYNC", "ASYNC", "FASTSYNC"]
        if not value_allowed_none_or_none_sentinel(transport_type, allowed_values):
            raise ValueError(
                "Invalid value for `transport_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._transport_type = transport_type

    @property
    def creation_type(self):
        """
        **[Required]** Gets the creation_type of this CreateDataGuardAssociationDetails.
        Specifies whether to create the peer database in an existing DB system or in a new DB system.


        :return: The creation_type of this CreateDataGuardAssociationDetails.
        :rtype: str
        """
        return self._creation_type

    @creation_type.setter
    def creation_type(self, creation_type):
        """
        Sets the creation_type of this CreateDataGuardAssociationDetails.
        Specifies whether to create the peer database in an existing DB system or in a new DB system.


        :param creation_type: The creation_type of this CreateDataGuardAssociationDetails.
        :type: str
        """
        self._creation_type = creation_type

    @property
    def is_active_data_guard_enabled(self):
        """
        Gets the is_active_data_guard_enabled of this CreateDataGuardAssociationDetails.
        True if active Data Guard is enabled.


        :return: The is_active_data_guard_enabled of this CreateDataGuardAssociationDetails.
        :rtype: bool
        """
        return self._is_active_data_guard_enabled

    @is_active_data_guard_enabled.setter
    def is_active_data_guard_enabled(self, is_active_data_guard_enabled):
        """
        Sets the is_active_data_guard_enabled of this CreateDataGuardAssociationDetails.
        True if active Data Guard is enabled.


        :param is_active_data_guard_enabled: The is_active_data_guard_enabled of this CreateDataGuardAssociationDetails.
        :type: bool
        """
        self._is_active_data_guard_enabled = is_active_data_guard_enabled

    @property
    def peer_db_unique_name(self):
        """
        Gets the peer_db_unique_name of this CreateDataGuardAssociationDetails.
        Specifies the `DB_UNIQUE_NAME` of the peer database to be created.


        :return: The peer_db_unique_name of this CreateDataGuardAssociationDetails.
        :rtype: str
        """
        return self._peer_db_unique_name

    @peer_db_unique_name.setter
    def peer_db_unique_name(self, peer_db_unique_name):
        """
        Sets the peer_db_unique_name of this CreateDataGuardAssociationDetails.
        Specifies the `DB_UNIQUE_NAME` of the peer database to be created.


        :param peer_db_unique_name: The peer_db_unique_name of this CreateDataGuardAssociationDetails.
        :type: str
        """
        self._peer_db_unique_name = peer_db_unique_name

    @property
    def peer_sid_prefix(self):
        """
        Gets the peer_sid_prefix of this CreateDataGuardAssociationDetails.
        Specifies a prefix for the `Oracle SID` of the database to be created.


        :return: The peer_sid_prefix of this CreateDataGuardAssociationDetails.
        :rtype: str
        """
        return self._peer_sid_prefix

    @peer_sid_prefix.setter
    def peer_sid_prefix(self, peer_sid_prefix):
        """
        Sets the peer_sid_prefix of this CreateDataGuardAssociationDetails.
        Specifies a prefix for the `Oracle SID` of the database to be created.


        :param peer_sid_prefix: The peer_sid_prefix of this CreateDataGuardAssociationDetails.
        :type: str
        """
        self._peer_sid_prefix = peer_sid_prefix

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ExecutionPlanStatsComparision(object):
    """
    The comparison report of the SQL execution plan statistics in the original and modified plan.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ExecutionPlanStatsComparision object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param original:
            The value to assign to the original property of this ExecutionPlanStatsComparision.
        :type original: oci.database_management.models.SqlTuningTaskPlanStats

        :param modified:
            The value to assign to the modified property of this ExecutionPlanStatsComparision.
        :type modified: oci.database_management.models.SqlTuningTaskPlanStats

        """
        self.swagger_types = {
            'original': 'SqlTuningTaskPlanStats',
            'modified': 'SqlTuningTaskPlanStats'
        }

        self.attribute_map = {
            'original': 'original',
            'modified': 'modified'
        }

        self._original = None
        self._modified = None

    @property
    def original(self):
        """
        **[Required]** Gets the original of this ExecutionPlanStatsComparision.

        :return: The original of this ExecutionPlanStatsComparision.
        :rtype: oci.database_management.models.SqlTuningTaskPlanStats
        """
        return self._original

    @original.setter
    def original(self, original):
        """
        Sets the original of this ExecutionPlanStatsComparision.

        :param original: The original of this ExecutionPlanStatsComparision.
        :type: oci.database_management.models.SqlTuningTaskPlanStats
        """
        self._original = original

    @property
    def modified(self):
        """
        **[Required]** Gets the modified of this ExecutionPlanStatsComparision.

        :return: The modified of this ExecutionPlanStatsComparision.
        :rtype: oci.database_management.models.SqlTuningTaskPlanStats
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """
        Sets the modified of this ExecutionPlanStatsComparision.

        :param modified: The modified of this ExecutionPlanStatsComparision.
        :type: oci.database_management.models.SqlTuningTaskPlanStats
        """
        self._modified = modified

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RedeemableUser(object):
    """
    The email object for a user that can redeem rewards.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RedeemableUser object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param email_id:
            The value to assign to the email_id property of this RedeemableUser.
        :type email_id: str

        """
        self.swagger_types = {
            'email_id': 'str'
        }

        self.attribute_map = {
            'email_id': 'emailId'
        }

        self._email_id = None

    @property
    def email_id(self):
        """
        **[Required]** Gets the email_id of this RedeemableUser.
        The email ID for a user that can redeem rewards.


        :return: The email_id of this RedeemableUser.
        :rtype: str
        """
        return self._email_id

    @email_id.setter
    def email_id(self, email_id):
        """
        Sets the email_id of this RedeemableUser.
        The email ID for a user that can redeem rewards.


        :param email_id: The email_id of this RedeemableUser.
        :type: str
        """
        self._email_id = email_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
